@@ -22,12 +22,15 @@ from multiprocessing.pool import ThreadPool
 import os
 
 import pprint
+
+from ambari_agent.models.commands import CommandStatus
 from ambari_commons import shell
 
 from unittest import TestCase
 import threading
 import tempfile
 import time
+import traceback
 from threading import Thread
 
 from mock.mock import MagicMock, patch
@@ -43,8 +46,10 @@ from ambari_agent.FileCache import FileCache
 from ambari_agent.PythonExecutor import PythonExecutor
 from ambari_commons import OSCheck
 from only_for_platform import get_platform, os_distro_value, PLATFORM_WINDOWS
+from ambari_agent.InitializerModule import InitializerModule
+from ambari_agent.ConfigurationBuilder import ConfigurationBuilder
 
-class TestCustomServiceOrchestrator(TestCase):
+class TestCustomServiceOrchestrator:#(TestCase):
 
 
   def setUp(self):
@@ -63,83 +68,6 @@ class TestCustomServiceOrchestrator(TestCase):
     self.config.set('python', 'custom_actions_dir', tmpdir)
 
 
-  @patch.object(OSCheck, "os_distribution", new = MagicMock(return_value = os_distro_value))
-  @patch.object(FileCache, "__init__")
-  def test_add_reg_listener_to_controller(self, FileCache_mock):
-    FileCache_mock.return_value = None
-    dummy_controller = MagicMock()
-    config = AmbariConfig()
-    tempdir = tempfile.gettempdir()
-    config.set('agent', 'prefix', tempdir)
-    CustomServiceOrchestrator(config, dummy_controller)
-    self.assertTrue(dummy_controller.registration_listeners.append.called)
-
-
-  @patch.object(OSCheck, "os_distribution", new = MagicMock(return_value = os_distro_value))
-  @patch.object(CustomServiceOrchestrator, 'decompressClusterHostInfo')
-  @patch("ambari_agent.hostname.public_hostname")
-  @patch("os.path.isfile")
-  @patch("os.unlink")
-  @patch.object(FileCache, "__init__")
-  def test_dump_command_to_json(self, FileCache_mock, unlink_mock,
-                                isfile_mock, hostname_mock,
-                                decompress_cluster_host_info_mock):
-    FileCache_mock.return_value = None
-    hostname_mock.return_value = "test.hst"
-    command = {
-      'commandType': 'EXECUTION_COMMAND',
-      'role': u'DATANODE',
-      'roleCommand': u'INSTALL',
-      'commandId': '1-1',
-      'taskId': 3,
-      'clusterName': u'cc',
-      'serviceName': u'HDFS',
-      'configurations':{'global' : {}},
-      'configurationTags':{'global' : { 'tag': 'v1' }},
-      'clusterHostInfo':{'namenode_host' : ['1'],
-                         'slave_hosts'   : ['0', '1'],
-                         'all_hosts'     : ['h1.hortonworks.com', 'h2.hortonworks.com'],
-                         'all_ping_ports': ['8670:0,1']},
-      'hostLevelParams':{}
-    }
-    
-    decompress_cluster_host_info_mock.return_value = {'namenode_host' : ['h2.hortonworks.com'],
-                         'slave_hosts'   : ['h1.hortonworks.com', 'h2.hortonworks.com'],
-                         'all_hosts'     : ['h1.hortonworks.com', 'h2.hortonworks.com'],
-                         'all_ping_ports': ['8670', '8670']}
-    
-    config = AmbariConfig()
-    tempdir = tempfile.gettempdir()
-    config.set('agent', 'prefix', tempdir)
-    dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(config, dummy_controller)
-    isfile_mock.return_value = True
-    # Test dumping EXECUTION_COMMAND
-    json_file = orchestrator.dump_command_to_json(command)
-    self.assertTrue(os.path.exists(json_file))
-    self.assertTrue(os.path.getsize(json_file) > 0)
-    if get_platform() != PLATFORM_WINDOWS:
-      self.assertEqual(oct(os.stat(json_file).st_mode & 0777), '0600')
-    self.assertTrue(json_file.endswith("command-3.json"))
-    self.assertTrue(decompress_cluster_host_info_mock.called)
-    os.unlink(json_file)
-    # Test dumping STATUS_COMMAND
-    command['commandType']='STATUS_COMMAND'
-    decompress_cluster_host_info_mock.reset_mock()
-    json_file = orchestrator.dump_command_to_json(command)
-    self.assertTrue(os.path.exists(json_file))
-    self.assertTrue(os.path.getsize(json_file) > 0)
-    if get_platform() != PLATFORM_WINDOWS:
-      self.assertEqual(oct(os.stat(json_file).st_mode & 0777), '0600')
-    self.assertTrue(json_file.endswith("status_command.json"))
-    self.assertFalse(decompress_cluster_host_info_mock.called)
-    os.unlink(json_file)
-    # Testing side effect of dump_command_to_json
-    self.assertEquals(command['public_hostname'], "test.hst")
-    self.assertEquals(command['agentConfigParams']['agent']['parallel_execution'], 0)
-    self.assertTrue(unlink_mock.called)
-
-
   @patch.object(OSCheck, "os_distribution", new = MagicMock(return_value = os_distro_value))
   @patch("ambari_agent.hostname.public_hostname")
   @patch("os.path.isfile")
@@ -171,11 +99,11 @@ class TestCustomServiceOrchestrator(TestCase):
       'hostLevelParams':{}
     }
 
-    config = AmbariConfig()
     tempdir = tempfile.gettempdir()
-    config.set('agent', 'prefix', tempdir)
-    dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    initializer_module.config.set('agent', 'prefix', tempdir)
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     isfile_mock.return_value = True
     # Test dumping EXECUTION_COMMAND
     json_file = orchestrator.dump_command_to_json(command)
@@ -194,8 +122,7 @@ class TestCustomServiceOrchestrator(TestCase):
     self.assertTrue(json_file.endswith("command-3.json"))
     os.unlink(json_file)
     # Testing side effect of dump_command_to_json
-    self.assertEquals(command['public_hostname'], "test.hst")
-    self.assertEquals(command['agentConfigParams']['agent']['parallel_execution'], 0)
+    self.assertNotEquals(command['clusterHostInfo'], {})
     self.assertTrue(unlink_mock.called)
 
   @patch.object(OSCheck, "os_distribution", new = MagicMock(return_value = os_distro_value))
@@ -205,7 +132,9 @@ class TestCustomServiceOrchestrator(TestCase):
     FileCache_mock.return_value = None
     dummy_controller = MagicMock()
     config = AmbariConfig()
-    orchestrator = CustomServiceOrchestrator(config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     # Testing existing path
     exists_mock.return_value = True
     path = orchestrator.\
@@ -220,6 +149,7 @@ class TestCustomServiceOrchestrator(TestCase):
     except AgentException:
       pass # Expected
 
+  @patch.object(ConfigurationBuilder, "get_configuration")
   @patch.object(FileCache, "get_custom_resources_subdir")
   @patch.object(CustomServiceOrchestrator, "resolve_script_path")
   @patch.object(CustomServiceOrchestrator, "resolve_hook_script_path")
@@ -235,15 +165,17 @@ class TestCustomServiceOrchestrator(TestCase):
                       get_host_scripts_base_dir_mock, 
                       resolve_hook_script_path_mock, 
                       resolve_script_path_mock,
-                      get_custom_resources_subdir_mock):
+                      get_custom_resources_subdir_mock, get_configuration_mock):
     
     FileCache_mock.return_value = None
     command = {
       'commandType' : 'EXECUTION_COMMAND',
       'role' : 'REGION_SERVER',
-      'hostLevelParams' : {
+      'clusterLevelParams' : {
         'stack_name' : 'HDP',
         'stack_version' : '2.0.7',
+      },
+      'ambariLevelParams': {
         'jdk_location' : 'some_location'
       },
       'commandParams': {
@@ -253,8 +185,10 @@ class TestCustomServiceOrchestrator(TestCase):
         'service_package_folder' : 'HBASE'
       },
       'taskId' : '3',
-      'roleCommand': 'INSTALL'
+      'roleCommand': 'INSTALL',
+      'clusterId': '-1',
     }
+    get_configuration_mock.return_value = command
     
     get_host_scripts_base_dir_mock.return_value = "/host_scripts"
     get_service_base_dir_mock.return_value = "/basedir/"
@@ -262,8 +196,9 @@ class TestCustomServiceOrchestrator(TestCase):
     resolve_hook_script_path_mock.return_value = \
       ('/hooks_dir/prefix-command/scripts/hook.py',
        '/hooks_dir/prefix-command')
-    dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(self.config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     unix_process_id = 111
     orchestrator.commands_in_progress = {command['taskId']: unix_process_id}
     get_hook_base_dir_mock.return_value = "/hooks/"
@@ -278,6 +213,23 @@ class TestCustomServiceOrchestrator(TestCase):
     self.assertTrue(run_file_mock.called)
     self.assertEqual(run_file_mock.call_count, 3)
 
+    # running a status command
+    run_file_mock.reset_mock()
+    def return_traceback(*args, **kwargs):
+      return {
+        'stderr': traceback.format_exc(),
+        'stdout': '',
+        'exitcode': 0,
+      }
+    run_file_mock.side_effect = return_traceback
+
+    status_command = dict(command)
+    status_command['commandType'] = 'STATUS_COMMAND'
+    del status_command['taskId']
+    del status_command['roleCommand']
+    ret = orchestrator.runCommand(status_command, "out.txt", "err.txt")
+    self.assertEqual('None\n', ret['stderr'])
+
     run_file_mock.reset_mock()
 
     # Case when we force another command
@@ -311,6 +263,7 @@ class TestCustomServiceOrchestrator(TestCase):
 
     pass
 
+  @patch.object(ConfigurationBuilder, "get_configuration")
   @patch("ambari_commons.shell.kill_process_with_children")
   @patch.object(CustomServiceOrchestrator, "resolve_script_path")
   @patch.object(CustomServiceOrchestrator, "resolve_hook_script_path")
@@ -325,13 +278,15 @@ class TestCustomServiceOrchestrator(TestCase):
                       get_hook_base_dir_mock, get_service_base_dir_mock,
                       get_host_scripts_base_dir_mock,
                       resolve_hook_script_path_mock, resolve_script_path_mock,
-                      kill_process_with_children_mock):
+                      kill_process_with_children_mock, get_configuration_mock):
     FileCache_mock.return_value = None
     command = {
       'role' : 'REGION_SERVER',
-      'hostLevelParams' : {
+      'clusterLevelParams' : {
         'stack_name' : 'HDP',
-        'stack_version' : '2.0.7',
+        'stack_version' : '2.0.7'
+      },
+      'ambariLevelParams': {
         'jdk_location' : 'some_location'
       },
       'commandParams': {
@@ -341,17 +296,20 @@ class TestCustomServiceOrchestrator(TestCase):
         'service_package_folder' : 'HBASE'
       },
       'taskId' : '3',
-      'roleCommand': 'INSTALL'
+      'roleCommand': 'INSTALL',
+      'clusterId': '-1'
     }
-    
+    get_configuration_mock.return_value = command
+        
     get_host_scripts_base_dir_mock.return_value = "/host_scripts"
     get_service_base_dir_mock.return_value = "/basedir/"
     resolve_script_path_mock.return_value = "/basedir/scriptpath"
     resolve_hook_script_path_mock.return_value = \
       ('/hooks_dir/prefix-command/scripts/hook.py',
        '/hooks_dir/prefix-command')
-    dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(self.config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     unix_process_id = 111
     orchestrator.commands_in_progress = {command['taskId']: unix_process_id}
     get_hook_base_dir_mock.return_value = "/hooks/"
@@ -390,6 +348,7 @@ class TestCustomServiceOrchestrator(TestCase):
       pass
 
   @patch.object(OSCheck, "os_distribution", new = MagicMock(return_value = os_distro_value))
+  @patch.object(ConfigurationBuilder, "get_configuration")
   @patch.object(CustomServiceOrchestrator, "get_py_executor")
   @patch("ambari_commons.shell.kill_process_with_children")
   @patch.object(FileCache, "__init__")
@@ -397,7 +356,7 @@ class TestCustomServiceOrchestrator(TestCase):
   @patch.object(CustomServiceOrchestrator, "resolve_hook_script_path")
   def test_cancel_backgound_command(self, resolve_hook_script_path_mock,
                                     resolve_script_path_mock, FileCache_mock, kill_process_with_children_mock,
-                                    get_py_executor_mock):
+                                    get_py_executor_mock, get_configuration_mock):
     FileCache_mock.return_value = None
     FileCache_mock.cache_dir = MagicMock()
     resolve_hook_script_path_mock.return_value = None
@@ -407,10 +366,14 @@ class TestCustomServiceOrchestrator(TestCase):
     cfg.set('agent', 'prefix', '.')
     cfg.set('agent', 'cache_dir', 'background_tasks')
 
-    actionQueue = ActionQueue(cfg, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    
+    actionQueue = ActionQueue(initializer_module)
+    orchestrator = CustomServiceOrchestrator(initializer_module)
 
-    dummy_controller.actionQueue = actionQueue
-    orchestrator = CustomServiceOrchestrator(cfg, dummy_controller)
+    initializer_module.actionQueue = actionQueue
+    
     orchestrator.file_cache = MagicMock()
     def f (a, b):
       return ""
@@ -437,8 +400,10 @@ class TestCustomServiceOrchestrator(TestCase):
 
     actionQueue.on_background_command_complete_callback = TestActionQueue.wraped(actionQueue.on_background_command_complete_callback, command_complete_w, None)
     execute_command = copy.deepcopy(TestActionQueue.TestActionQueue.background_command)
+    get_configuration_mock.return_value = execute_command
+    
     actionQueue.put([execute_command])
-    actionQueue.processBackgroundQueueSafeEmpty()
+    actionQueue.process_background_queue_safe_empty()
 
     time.sleep(.1)
 
@@ -456,9 +421,10 @@ class TestCustomServiceOrchestrator(TestCase):
 
     runningCommand = actionQueue.commandStatuses.get_command_status(19)
     self.assertTrue(runningCommand is not None)
-    self.assertEqual(runningCommand['status'], ActionQueue.FAILED_STATUS)
+    self.assertEqual(runningCommand['status'], CommandStatus.failed)
 
 
+  @patch.object(ConfigurationBuilder, "get_configuration")
   @patch.object(AmbariConfig, "get")
   @patch.object(CustomServiceOrchestrator, "dump_command_to_json")
   @patch.object(PythonExecutor, "run_file")
@@ -466,7 +432,7 @@ class TestCustomServiceOrchestrator(TestCase):
   @patch.object(FileCache, "get_custom_actions_base_dir")
   def test_runCommand_custom_action(self, get_custom_actions_base_dir_mock,
                                     FileCache_mock,
-                                    run_file_mock, dump_command_to_json_mock, ambari_config_get):
+                                    run_file_mock, dump_command_to_json_mock, ambari_config_get, get_configuration_mock):
     ambari_config_get.return_value = "0"
     FileCache_mock.return_value = None
     get_custom_actions_base_dir_mock.return_value = "some path"
@@ -477,13 +443,22 @@ class TestCustomServiceOrchestrator(TestCase):
         'script_type': 'PYTHON',
         'script': 'some_custom_action.py',
         'command_timeout': '600',
+      },
+      'ambariLevelParams': {
         'jdk_location' : 'some_location'
       },
       'taskId' : '3',
-      'roleCommand': 'ACTIONEXECUTE'
+      'roleCommand': 'ACTIONEXECUTE',
+      'clusterId': '-1',
     }
-    dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(self.config, dummy_controller)
+    get_configuration_mock.return_value = command
+    
+    initializer_module = InitializerModule()
+    initializer_module.config = self.config
+    initializer_module.init()
+    
+    
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     unix_process_id = 111
     orchestrator.commands_in_progress = {command['taskId']: unix_process_id}
     # normal run case
@@ -505,7 +480,9 @@ class TestCustomServiceOrchestrator(TestCase):
   def test_resolve_hook_script_path(self, FileCache_mock, isfile_mock):
     FileCache_mock.return_value = None
     dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(self.config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     # Testing None param
     res1 = orchestrator.resolve_hook_script_path(None, "prefix", "command",
                                             "script_type")
@@ -535,7 +512,9 @@ class TestCustomServiceOrchestrator(TestCase):
       'configurations':{}
     }
     dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(self.config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    orchestrator = CustomServiceOrchestrator(initializer_module)
     # Test alive case
     runCommand_mock.return_value = {
       "exitcode" : 0
@@ -552,6 +531,7 @@ class TestCustomServiceOrchestrator(TestCase):
     self.assertEqual(runCommand_mock.return_value, status)
 
 
+  @patch.object(ConfigurationBuilder, "get_configuration")
   @patch.object(CustomServiceOrchestrator, "get_py_executor")
   @patch.object(CustomServiceOrchestrator, "dump_command_to_json")
   @patch.object(FileCache, "__init__")
@@ -559,7 +539,7 @@ class TestCustomServiceOrchestrator(TestCase):
   def test_runCommand_background_action(self, get_custom_actions_base_dir_mock,
                                     FileCache_mock,
                                     dump_command_to_json_mock,
-                                    get_py_executor_mock):
+                                    get_py_executor_mock, get_configuration_mock):
     FileCache_mock.return_value = None
     get_custom_actions_base_dir_mock.return_value = "some path"
     _, script = tempfile.mkstemp()
@@ -569,21 +549,25 @@ class TestCustomServiceOrchestrator(TestCase):
         'script_type': 'PYTHON',
         'script': 'some_custom_action.py',
         'command_timeout': '600',
+      },
+      'ambariLevelParams': {
         'jdk_location' : 'some_location'
       },
+      'clusterId': '-1',
       'taskId' : '13',
       'roleCommand': 'ACTIONEXECUTE',
       'commandType': 'BACKGROUND_EXECUTION_COMMAND',
       '__handle': BackgroundCommandExecutionHandle({'taskId': '13'}, 13,
                                                    MagicMock(), MagicMock())
     }
-    dummy_controller = MagicMock()
-    orchestrator = CustomServiceOrchestrator(self.config, dummy_controller)
+    initializer_module = InitializerModule()
+    initializer_module.init()
+    orchestrator = CustomServiceOrchestrator(initializer_module)
 
     import TestActionQueue
     pyex = PythonExecutor(orchestrator.tmp_dir, orchestrator.config)
     TestActionQueue.patch_output_file(pyex)
-    pyex.condenseOutput = MagicMock()
+    pyex.condense_output = MagicMock()
     get_py_executor_mock.return_value = pyex
     orchestrator.dump_command_to_json = MagicMock()
 
