@@ -26,6 +26,8 @@ UPGRADE_TYPE_HOST_ORDERED = "host_ordered"
 
 AGENT_TMP_DIR = "/var/lib/ambari-agent/tmp"
 
+LOGFEEDER_CONF_DIR = "/usr/lib/ambari-logsearch-logfeeder/conf"
+
 class SERVICE:
   """
   Constants for service names to avoid hardcoding strings.
@@ -52,3 +54,4 @@ class SERVICE:
   YARN = "YARN"
   ZEPPELIN = "ZEPPELIN"
   ZOOKEEPER = "ZOOKEEPER"
+  HBASE = "HBASE"
\ No newline at end of file
