@@ -39,9 +39,9 @@ import org.apache.ambari.server.StaticallyInject;
 import org.apache.ambari.server.actionmanager.ActionManager;
 import org.apache.ambari.server.actionmanager.HostRoleCommandFactory;
 import org.apache.ambari.server.agent.HeartBeatHandler;
-import org.apache.ambari.server.agent.rest.AgentResource;
 import org.apache.ambari.server.api.AmbariErrorHandler;
 import org.apache.ambari.server.api.AmbariPersistFilter;
+import org.apache.ambari.server.api.ContentTypeOverrideFilter;
 import org.apache.ambari.server.api.MethodOverrideFilter;
 import org.apache.ambari.server.api.UserNameOverrideFilter;
 import org.apache.ambari.server.api.rest.BootStrapResource;
@@ -52,7 +52,6 @@ import org.apache.ambari.server.api.services.PersistKeyValueImpl;
 import org.apache.ambari.server.api.services.PersistKeyValueService;
 import org.apache.ambari.server.api.services.stackadvisor.StackAdvisorBlueprintProcessor;
 import org.apache.ambari.server.api.services.stackadvisor.StackAdvisorHelper;
-import org.apache.ambari.server.audit.AuditLogger;
 import org.apache.ambari.server.audit.AuditLoggerModule;
 import org.apache.ambari.server.audit.request.RequestAuditLogger;
 import org.apache.ambari.server.bootstrap.BootStrapImpl;
@@ -60,6 +59,10 @@ import org.apache.ambari.server.checks.DatabaseConsistencyCheckHelper;
 import org.apache.ambari.server.checks.DatabaseConsistencyCheckResult;
 import org.apache.ambari.server.configuration.ComponentSSLConfiguration;
 import org.apache.ambari.server.configuration.Configuration;
+import org.apache.ambari.server.configuration.SingleFileWatch;
+import org.apache.ambari.server.configuration.spring.AgentStompConfig;
+import org.apache.ambari.server.configuration.spring.ApiSecurityConfig;
+import org.apache.ambari.server.configuration.spring.ApiStompConfig;
 import org.apache.ambari.server.controller.internal.AbstractControllerResourceProvider;
 import org.apache.ambari.server.controller.internal.AmbariPrivilegeResourceProvider;
 import org.apache.ambari.server.controller.internal.BaseClusterRequest;
@@ -76,6 +79,10 @@ import org.apache.ambari.server.controller.internal.UserPrivilegeResourceProvide
 import org.apache.ambari.server.controller.internal.ViewPermissionResourceProvider;
 import org.apache.ambari.server.controller.metrics.ThreadPoolEnabledPropertyProvider;
 import org.apache.ambari.server.controller.utilities.KerberosChecker;
+import org.apache.ambari.server.controller.utilities.KerberosIdentityCleaner;
+import org.apache.ambari.server.events.AmbariPropertiesChangedEvent;
+import org.apache.ambari.server.events.publishers.AmbariEventPublisher;
+import org.apache.ambari.server.ldap.LdapModule;
 import org.apache.ambari.server.metrics.system.MetricsService;
 import org.apache.ambari.server.orm.GuiceJpaInitializer;
 import org.apache.ambari.server.orm.PersistenceType;
@@ -87,9 +94,11 @@ import org.apache.ambari.server.orm.dao.PermissionDAO;
 import org.apache.ambari.server.orm.dao.PrincipalDAO;
 import org.apache.ambari.server.orm.dao.PrivilegeDAO;
 import org.apache.ambari.server.orm.dao.ResourceDAO;
+import org.apache.ambari.server.orm.dao.TopologyRequestDAO;
 import org.apache.ambari.server.orm.dao.UserDAO;
 import org.apache.ambari.server.orm.dao.ViewInstanceDAO;
 import org.apache.ambari.server.orm.entities.MetainfoEntity;
+import org.apache.ambari.server.orm.entities.UserEntity;
 import org.apache.ambari.server.resources.ResourceManager;
 import org.apache.ambari.server.resources.api.rest.GetResource;
 import org.apache.ambari.server.scheduler.ExecutionScheduleManager;
@@ -97,17 +106,11 @@ import org.apache.ambari.server.security.AmbariServerSecurityHeaderFilter;
 import org.apache.ambari.server.security.AmbariViewsSecurityHeaderFilter;
 import org.apache.ambari.server.security.CertificateManager;
 import org.apache.ambari.server.security.SecurityFilter;
-import org.apache.ambari.server.security.authorization.AmbariLdapAuthenticationProvider;
-import org.apache.ambari.server.security.authorization.AmbariLocalUserProvider;
-import org.apache.ambari.server.security.authorization.AmbariPamAuthenticationProvider;
-import org.apache.ambari.server.security.authorization.AmbariUserAuthorizationFilter;
-import org.apache.ambari.server.security.authorization.PermissionHelper;
 import org.apache.ambari.server.security.authorization.Users;
-import org.apache.ambari.server.security.authorization.internal.AmbariInternalAuthenticationProvider;
-import org.apache.ambari.server.security.ldap.AmbariLdapDataPopulator;
 import org.apache.ambari.server.security.unsecured.rest.CertificateDownload;
 import org.apache.ambari.server.security.unsecured.rest.CertificateSign;
 import org.apache.ambari.server.security.unsecured.rest.ConnectionInfo;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.KerberosKeytabController;
 import org.apache.ambari.server.stack.UpdateActiveRepoVersionOnStartup;
 import org.apache.ambari.server.state.Clusters;
 import org.apache.ambari.server.topology.AmbariContext;
@@ -124,17 +127,23 @@ import org.apache.ambari.server.view.ViewDirectoryWatcher;
 import org.apache.ambari.server.view.ViewRegistry;
 import org.apache.ambari.server.view.ViewThrottleFilter;
 import org.apache.commons.lang.StringUtils;
+import org.apache.http.HttpVersion;
 import org.apache.log4j.PropertyConfigurator;
 import org.apache.velocity.app.Velocity;
 import org.eclipse.jetty.server.Handler;
+import org.eclipse.jetty.server.HttpConfiguration;
+import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.NCSARequestLog;
+import org.eclipse.jetty.server.SecureRequestCustomizer;
 import org.eclipse.jetty.server.Server;
+import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.server.SessionIdManager;
-import org.eclipse.jetty.server.SessionManager;
+import org.eclipse.jetty.server.SslConnectionFactory;
 import org.eclipse.jetty.server.handler.HandlerCollection;
 import org.eclipse.jetty.server.handler.RequestLogHandler;
-import org.eclipse.jetty.server.nio.SelectChannelConnector;
-import org.eclipse.jetty.server.ssl.SslSelectChannelConnector;
+import org.eclipse.jetty.server.handler.gzip.GzipHandler;
+import org.eclipse.jetty.server.session.DefaultSessionIdManager;
+import org.eclipse.jetty.server.session.SessionHandler;
 import org.eclipse.jetty.servlet.DefaultServlet;
 import org.eclipse.jetty.servlet.FilterHolder;
 import org.eclipse.jetty.servlet.ServletContextHandler;
@@ -148,12 +157,13 @@ import org.slf4j.bridge.SLF4JBridgeHandler;
 import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
 import org.springframework.context.support.ClassPathXmlApplicationContext;
 import org.springframework.security.core.context.SecurityContextHolder;
-import org.springframework.security.crypto.password.PasswordEncoder;
-import org.springframework.web.context.WebApplicationContext;
+import org.springframework.web.context.ContextLoaderListener;
 import org.springframework.web.context.request.RequestContextListener;
-import org.springframework.web.context.support.GenericWebApplicationContext;
+import org.springframework.web.context.support.AnnotationConfigWebApplicationContext;
 import org.springframework.web.filter.DelegatingFilterProxy;
+import org.springframework.web.servlet.DispatcherServlet;
 
+import com.google.common.base.Joiner;
 import com.google.common.util.concurrent.ServiceManager;
 import com.google.gson.Gson;
 import com.google.inject.Guice;
@@ -165,10 +175,11 @@ import com.google.inject.name.Named;
 import com.google.inject.persist.Transactional;
 import com.sun.jersey.spi.container.servlet.ServletContainer;
 
+
 @Singleton
 public class AmbariServer {
   public static final String VIEWS_URL_PATTERN = "/api/v1/views/*";
-  private static Logger LOG = LoggerFactory.getLogger(AmbariServer.class);
+  private static final Logger LOG = LoggerFactory.getLogger(AmbariServer.class);
 
   /**
    * The thread name prefix for threads handling agent requests.
@@ -187,6 +198,8 @@ public class AmbariServer {
    * Dispatcher types for webAppContext.addFilter.
    */
   public static final EnumSet<DispatcherType> DISPATCHER_TYPES = EnumSet.of(DispatcherType.REQUEST);
+  private static final int DEFAULT_ACCEPTORS_COUNT = 1;
+  private static final String[] DEPRECATED_SSL_PROTOCOLS = new String[] {"TLSv1"};
 
   static {
     Velocity.setProperty("runtime.log.logsystem.log4j.logger", VELOCITY_LOG_CATEGORY);
@@ -219,8 +232,6 @@ public class AmbariServer {
   public volatile boolean running = true; // true while controller runs
 
   final String CONTEXT_PATH = "/";
-  final String SPRING_CONTEXT_LOCATION =
-      "classpath:/webapp/WEB-INF/spring-security.xml";
   final String DISABLED_ENTRIES_SPLITTER = "\\|";
 
   @Inject
@@ -264,13 +275,7 @@ public class AmbariServer {
    * Session manager.
    */
   @Inject
-  SessionManager sessionManager;
-
-  /**
-   * Session ID manager.
-   */
-  @Inject
-  SessionIdManager sessionIdManager;
+  SessionHandler sessionHandler;
 
   @Inject
   DelegatingFilterProxy springSecurityFilter;
@@ -278,6 +283,9 @@ public class AmbariServer {
   @Inject
   ViewDirectoryWatcher viewDirectoryWatcher;
 
+  @Inject
+  SessionHandlerConfigurer sessionHandlerConfigurer;
+
   public String getServerOsType() {
     return configs.getServerOsType();
   }
@@ -299,6 +307,10 @@ public class AmbariServer {
     return clusterController;
   }
 
+  public static void setController(AmbariManagementController controller) {
+    clusterController = controller;
+  }
+
   @SuppressWarnings("deprecation")
   public void run() throws Exception {
     setupJulLogging();
@@ -306,10 +318,23 @@ public class AmbariServer {
 
     performStaticInjection();
     initDB();
-    server = new Server();
+    // Client Jetty thread pool - widen the thread pool if needed !
+    Integer clientAcceptors = configs.getClientApiAcceptors() != null ? configs
+      .getClientApiAcceptors() : DEFAULT_ACCEPTORS_COUNT;
+
+    server = configureJettyThreadPool(clientAcceptors, CLIENT_THREAD_POOL_NAME,
+      configs.getClientThreadPoolSize());
+
+    final SessionIdManager sessionIdManager = new DefaultSessionIdManager(server);
+    sessionHandler.setSessionIdManager(sessionIdManager);
     server.setSessionIdManager(sessionIdManager);
-    server.setSendServerVersion(false);
-    Server serverForAgent = new Server();
+
+    // Agent Jetty thread pool - widen the thread pool if needed !
+    Integer agentAcceptors = configs.getAgentApiAcceptors() != null ?
+      configs.getAgentApiAcceptors() : DEFAULT_ACCEPTORS_COUNT;
+
+    Server serverForAgent = configureJettyThreadPool(agentAcceptors * 2,
+      AGENT_THREAD_POOL_NAME, configs.getAgentThreadPoolSize());
 
     setSystemProperties(configs);
 
@@ -322,48 +347,33 @@ public class AmbariServer {
       ConfigurableListableBeanFactory factory = parentSpringAppContext.
           getBeanFactory();
 
-      factory.registerSingleton("guiceInjector", injector);
-      factory.registerSingleton("ambariConfiguration", injector.getInstance(Configuration.class));
+      factory.registerSingleton("injector", injector);
+      //todo unable to register Users class as Spring @Bean since it tries to process @Inject annotations, investigate
       factory.registerSingleton("ambariUsers", injector.getInstance(Users.class));
-      factory.registerSingleton("passwordEncoder",
-        injector.getInstance(PasswordEncoder.class));
-      factory.registerSingleton("auditLogger",
-        injector.getInstance(AuditLogger.class));
-      factory.registerSingleton("permissionHelper",
-        injector.getInstance(PermissionHelper.class));
-      factory.registerSingleton("ambariLdapAuthenticationProvider",
-        injector.getInstance(AmbariLdapAuthenticationProvider.class));
-      factory.registerSingleton("ambariLocalAuthenticationProvider",
-        injector.getInstance(AmbariLocalUserProvider.class));
-      factory.registerSingleton("ambariLdapDataPopulator",
-        injector.getInstance(AmbariLdapDataPopulator.class));
-      factory.registerSingleton("ambariUserAuthorizationFilter",
-        injector.getInstance(AmbariUserAuthorizationFilter.class));
-      factory.registerSingleton("ambariInternalAuthenticationProvider",
-        injector.getInstance(AmbariInternalAuthenticationProvider.class));
-      factory.registerSingleton("ambariPamAuthenticationProvider",
-	      injector.getInstance(AmbariPamAuthenticationProvider.class));
 
-      // Spring Security xml config depends on this Bean
-      String[] contextLocations = {SPRING_CONTEXT_LOCATION};
-      ClassPathXmlApplicationContext springAppContext = new
-          ClassPathXmlApplicationContext(contextLocations, parentSpringAppContext);
+      //create spring context for web api
+      AnnotationConfigWebApplicationContext apiContext = new AnnotationConfigWebApplicationContext();
+      apiContext.setParent(parentSpringAppContext);
+      apiContext.register(ApiSecurityConfig.class);
+      //refresh will be called in ContextLoaderListener
+
+      AnnotationConfigWebApplicationContext apiDispatcherContext = new AnnotationConfigWebApplicationContext();
+      apiDispatcherContext.register(ApiStompConfig.class);
+      DispatcherServlet apiDispatcherServlet = new DispatcherServlet(apiDispatcherContext);
+
+      AnnotationConfigWebApplicationContext agentDispatcherContext = new AnnotationConfigWebApplicationContext();
+      agentDispatcherContext.register(AgentStompConfig.class);
+      DispatcherServlet agentDispatcherServlet = new DispatcherServlet(agentDispatcherContext);
 
       ServletContextHandler root = new ServletContextHandler(
           ServletContextHandler.SECURITY | ServletContextHandler.SESSIONS);
 
       configureRootHandler(root);
-      configureSessionManager(sessionManager);
-      root.getSessionHandler().setSessionManager(sessionManager);
+      sessionHandlerConfigurer.configureSessionHandler(sessionHandler);
+      root.setSessionHandler(sessionHandler);
 
-      // setting ambari web context
-      GenericWebApplicationContext springWebAppContext = new GenericWebApplicationContext();
-      springWebAppContext.setServletContext(root.getServletContext());
-      springWebAppContext.setParent(springAppContext);
-
-      root.getServletContext().setAttribute(
-          WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE,
-          springWebAppContext);
+      //ContextLoaderListener handles all work on registration in servlet container
+      root.addEventListener(new ContextLoaderListener(apiContext));
 
       certMan.initRootCert();
 
@@ -372,12 +382,17 @@ public class AmbariServer {
       ServletContextHandler agentroot = new ServletContextHandler(
           serverForAgent, "/", ServletContextHandler.NO_SESSIONS);
 
+      AnnotationConfigWebApplicationContext agentApiContext = new AnnotationConfigWebApplicationContext();
+      agentApiContext.setParent(parentSpringAppContext);
+
       if (configs.isAgentApiGzipped()) {
         configureHandlerCompression(agentroot);
       }
+      agentroot.addEventListener(new ContextLoaderListener(agentApiContext));
 
       ServletHolder rootServlet = root.addServlet(DefaultServlet.class, "/");
       rootServlet.setInitParameter("dirAllowed", "false");
+      rootServlet.setInitParameter("precompressed", "gzip=.gz");
       rootServlet.setInitOrder(1);
 
       /* Configure default servlet for agent server */
@@ -405,10 +420,10 @@ public class AmbariServer {
       // session-per-request strategy for api
       root.addFilter(new FilterHolder(injector.getInstance(AmbariPersistFilter.class)), "/api/*", DISPATCHER_TYPES);
       root.addFilter(new FilterHolder(new MethodOverrideFilter()), "/api/*", DISPATCHER_TYPES);
+      root.addFilter(new FilterHolder(new ContentTypeOverrideFilter()), "/api/*", DISPATCHER_TYPES);
 
       // register listener to capture request context
       root.addEventListener(new RequestContextListener());
-
       root.addFilter(new FilterHolder(springSecurityFilter), "/api/*", DISPATCHER_TYPES);
       root.addFilter(new FilterHolder(new UserNameOverrideFilter()), "/api/v1/users/*", DISPATCHER_TYPES);
 
@@ -420,18 +435,8 @@ public class AmbariServer {
 
       // Agents download cert on on-way connector but always communicate on
       // two-way connector for server-agent communication
-      SelectChannelConnector agentOneWayConnector = createSelectChannelConnectorForAgent(configs.getOneWayAuthPort(), false);
-      SelectChannelConnector agentTwoWayConnector = createSelectChannelConnectorForAgent(configs.getTwoWayAuthPort(), configs.isTwoWaySsl());
-
-      // Override acceptor defaults if configured or use Jetty defaults
-      Integer acceptors = configs.getAgentApiAcceptors() != null ?
-        configs.getAgentApiAcceptors() : agentOneWayConnector.getAcceptors();
-      agentOneWayConnector.setAcceptors(acceptors);
-      agentTwoWayConnector.setAcceptors(acceptors);
-
-      // Agent Jetty thread pool - widen the thread pool if needed !
-      configureJettyThreadPool(serverForAgent, acceptors * 2,
-        AGENT_THREAD_POOL_NAME, configs.getAgentThreadPoolSize());
+      ServerConnector agentOneWayConnector = createSelectChannelConnectorForAgent(serverForAgent, configs.getOneWayAuthPort(), false, agentAcceptors);
+      ServerConnector agentTwoWayConnector = createSelectChannelConnectorForAgent(serverForAgent, configs.getTwoWayAuthPort(), configs.isTwoWaySsl(), agentAcceptors);
 
       serverForAgent.addConnector(agentOneWayConnector);
       serverForAgent.addConnector(agentTwoWayConnector);
@@ -450,16 +455,35 @@ public class AmbariServer {
       root.addServlet(sh, "/api/v1/*");
       sh.setInitOrder(2);
 
+      ServletHolder springDispatcherServlet = new ServletHolder("springDispatcherServlet", apiDispatcherServlet);
+      springDispatcherServlet.setInitOrder(3);
+      root.addServlet(springDispatcherServlet, "/api/stomp/*");
+
+      ServletHolder agentSpringDispatcherServlet =
+          new ServletHolder("agentSpringDispatcherServlet", agentDispatcherServlet);
+      agentSpringDispatcherServlet.setInitOrder(2);
+      agentroot.addServlet(agentSpringDispatcherServlet, "/agent/stomp/*");
+
       SecurityContextHolder.setStrategyName(SecurityContextHolder.MODE_INHERITABLETHREADLOCAL);
 
       viewRegistry.readViewArchives();
 
-      enableLog4jMonitor(configsMap);
-
       //Check and load requestlog handler.
       loadRequestlogHandler(handlerList, serverForAgent, configsMap);
 
-      handlerList.addHandler(root);
+      enableLog4jMonitor(configsMap);
+
+      if (configs.isGzipHandlerEnabledForJetty()) {
+        GzipHandler gzipHandler = new GzipHandler();
+        gzipHandler.setHandler(root);
+        //TODO minimal set, perhaps is needed to add some other mime types
+        gzipHandler.setIncludedMimeTypes("text/html", "text/plain", "text/xml", "text/css", "application/javascript",
+          "application/x-javascript", "application/xml", "application/x-www-form-urlencoded", "application/json");
+        handlerList.addHandler(gzipHandler);
+      } else {
+        handlerList.addHandler(root);
+      }
+
       server.setHandler(handlerList);
 
       ServletHolder agent = new ServletHolder(ServletContainer.class);
@@ -471,7 +495,7 @@ public class AmbariServer {
       agentroot.addServlet(agent, "/agent/v1/*");
       agent.setInitOrder(3);
 
-      AgentResource.statHeartBeatHandler();
+      injector.getInstance(HeartBeatHandler.class).start();
       LOG.info("********** Started Heartbeat handler **********");
 
       ServletHolder cert = new ServletHolder(ServletContainer.class);
@@ -487,12 +511,7 @@ public class AmbariServer {
       File resourcesDirectory = new File(configs.getResourceDirPath());
       ServletHolder resources = new ServletHolder(DefaultServlet.class);
       resources.setInitParameter("resourceBase", resourcesDirectory.getParent());
-      // Allowing aliases can bypass some security constraints, but allows for following symlinks
-      // which are needed for mpacks. For example:
-      //   /var/lib/ambari-server/resources/stacks/HDP/2.6/services/BEACON ->
-      //   /var/lib/ambari-server/resources/mpacks/beacon-engine.mpack-1.1.0.0/addon-services/BEACON/1.1.0
-      // NOTE: Enabling aliases does not re-introduce the vulnerability described in CVE-2018-8003.
-      resources.setInitParameter("aliases", "true");
+      resources.setInitParameter("dirAllowed", "false");
       root.addServlet(resources, "/resources/*");
       resources.setInitOrder(5);
 
@@ -502,20 +521,13 @@ public class AmbariServer {
       }
 
       /* Configure the API server to use the NIO connectors */
-      SelectChannelConnector apiConnector = createSelectChannelConnectorForClient();
+      ServerConnector apiConnector = createSelectChannelConnectorForClient(server, clientAcceptors);
 
-      acceptors = configs.getClientApiAcceptors() != null ? configs
-        .getClientApiAcceptors() : apiConnector.getAcceptors();
-      apiConnector.setAcceptors(acceptors);
-
-      // Client Jetty thread pool - widen the thread pool if needed !
-      configureJettyThreadPool(server, acceptors, CLIENT_THREAD_POOL_NAME,
-        configs.getClientThreadPoolSize());
       server.addConnector(apiConnector);
 
       server.setStopAtShutdown(true);
       serverForAgent.setStopAtShutdown(true);
-      springAppContext.start();
+//todo remove      springAppContext.start();
 
       String osType = getServerOsType();
       if (osType == null || osType.isEmpty()) {
@@ -527,7 +539,8 @@ public class AmbariServer {
       LOG.info("********* Initializing Clusters **********");
       Clusters clusters = injector.getInstance(Clusters.class);
       StringBuilder clusterDump = new StringBuilder();
-      clusters.debugDump(clusterDump);
+      //TODO temporally commented because takes a lot of time on 5k cluster
+      //clusters.debugDump(clusterDump);
 
       LOG.info("********* Current Clusters State *********");
       LOG.info(clusterDump.toString());
@@ -555,11 +568,14 @@ public class AmbariServer {
           StateRecoveryManager.class);
 
       recoveryManager.doWork();
-
       /*
        * Start the server after controller state is recovered.
        */
       server.start();
+      handlerList.shareSessionCacheToViews(sessionHandler.getSessionCache());
+
+      //views initialization will reset inactive interval with default value, so we should set it after
+      sessionHandlerConfigurer.configureMaxInactiveInterval(sessionHandler);
 
       serverForAgent.start();
       LOG.info("********* Started Server **********");
@@ -606,9 +622,9 @@ public class AmbariServer {
    * @return org.eclipse.jetty.server.nio.SelectChannelConnector
    */
   @SuppressWarnings("deprecation")
-  private SelectChannelConnector createSelectChannelConnectorForAgent(int port, boolean needClientAuth) {
+  private ServerConnector createSelectChannelConnectorForAgent(Server server, int port, boolean needClientAuth, int acceptors) {
     Map<String, String> configsMap = configs.getConfigsMap();
-    SelectChannelConnector agentConnector;
+    ServerConnector agentConnector;
 
     if (configs.getAgentSSLAuthentication()) {
       String keystore = configsMap.get(Configuration.SRVR_KSTR_DIR.getKey()) + File.separator
@@ -619,25 +635,31 @@ public class AmbariServer {
 
       String srvrCrtPass = configsMap.get(Configuration.SRVR_CRT_PASS.getKey());
 
-      // Secured connector - default constructor sets trustAll = true for certs
-      SslContextFactory contextFactory = new SslContextFactory();
-      disableInsecureProtocols(contextFactory);
 
-      SslSelectChannelConnector agentSslConnector = new SslSelectChannelConnector(contextFactory);
-      agentSslConnector.setKeystore(keystore);
-      agentSslConnector.setTruststore(truststore);
-      agentSslConnector.setPassword(srvrCrtPass);
-      agentSslConnector.setKeyPassword(srvrCrtPass);
-      agentSslConnector.setTrustPassword(srvrCrtPass);
-      agentSslConnector.setKeystoreType(configsMap.get(Configuration.KSTR_TYPE.getKey()));
-      agentSslConnector.setTruststoreType(configsMap.get(Configuration.TSTR_TYPE.getKey()));
-      agentSslConnector.setNeedClientAuth(needClientAuth);
-      agentSslConnector.setRequestHeaderSize(configs.getHttpRequestHeaderSize());
-      agentSslConnector.setResponseHeaderSize(configs.getHttpResponseHeaderSize());
+      HttpConfiguration https_config = new HttpConfiguration();
+      https_config.addCustomizer(new SecureRequestCustomizer());
+      https_config.setRequestHeaderSize(configs.getHttpRequestHeaderSize());
+      https_config.setResponseHeaderSize(configs.getHttpResponseHeaderSize());
+      https_config.setSendServerVersion(false);
+
+      // Secured connector - default constructor sets trustAll = true for certs
+      SslContextFactory sslContextFactory = new SslContextFactory();
+      disableInsecureProtocols(sslContextFactory);
+      sslContextFactory.setKeyStorePath(keystore);
+      sslContextFactory.setTrustStorePath(truststore);
+      sslContextFactory.setKeyStorePassword(srvrCrtPass);
+      sslContextFactory.setKeyManagerPassword(srvrCrtPass);
+      sslContextFactory.setTrustStorePassword(srvrCrtPass);
+      sslContextFactory.setKeyStoreType(configsMap.get(Configuration.KSTR_TYPE.getKey()));
+      sslContextFactory.setTrustStoreType(configsMap.get(Configuration.TSTR_TYPE.getKey()));
+      sslContextFactory.setNeedClientAuth(needClientAuth);
+      ServerConnector agentSslConnector = new ServerConnector(server, acceptors, -1,
+        new SslConnectionFactory(sslContextFactory, HttpVersion.HTTP_1_1.toString()),
+        new HttpConnectionFactory(https_config));
       agentConnector = agentSslConnector;
     } else {
-      agentConnector = new SelectChannelConnector();
-      agentConnector.setMaxIdleTime(configs.getConnectionMaxIdleTime());
+      agentConnector = new ServerConnector(server, acceptors, -1);
+      agentConnector.setIdleTimeout(configs.getConnectionMaxIdleTime());
     }
 
     agentConnector.setPort(port);
@@ -646,10 +668,14 @@ public class AmbariServer {
   }
 
   @SuppressWarnings("deprecation")
-  private SelectChannelConnector createSelectChannelConnectorForClient() {
+  private ServerConnector createSelectChannelConnectorForClient(Server server, int acceptors) {
     Map<String, String> configsMap = configs.getConfigsMap();
-    SelectChannelConnector apiConnector;
+    ServerConnector apiConnector;
 
+    HttpConfiguration http_config = new HttpConfiguration();
+    http_config.setRequestHeaderSize(configs.getHttpRequestHeaderSize());
+    http_config.setResponseHeaderSize(configs.getHttpResponseHeaderSize());
+    http_config.setSendServerVersion(false);
     if (configs.getApiSSLAuthentication()) {
       String httpsKeystore = configsMap.get(Configuration.CLIENT_API_SSL_KSTR_DIR_NAME.getKey()) +
         File.separator + configsMap.get(Configuration.CLIENT_API_SSL_KSTR_NAME.getKey());
@@ -659,27 +685,28 @@ public class AmbariServer {
 
       String httpsCrtPass = configsMap.get(Configuration.CLIENT_API_SSL_CRT_PASS.getKey());
 
+      HttpConfiguration https_config = new HttpConfiguration(http_config);
+      https_config.addCustomizer(new SecureRequestCustomizer());
+      https_config.setSecurePort(configs.getClientSSLApiPort());
+
       SslContextFactory contextFactoryApi = new SslContextFactory();
       disableInsecureProtocols(contextFactoryApi);
-      SslSelectChannelConnector sapiConnector = new SslSelectChannelConnector(contextFactoryApi);
-      sapiConnector.setPort(configs.getClientSSLApiPort());
-      sapiConnector.setKeystore(httpsKeystore);
-      sapiConnector.setTruststore(httpsTruststore);
-      sapiConnector.setPassword(httpsCrtPass);
-      sapiConnector.setKeyPassword(httpsCrtPass);
-      sapiConnector.setTrustPassword(httpsCrtPass);
-      sapiConnector.setKeystoreType(configsMap.get(Configuration.CLIENT_API_SSL_KSTR_TYPE.getKey()));
-      sapiConnector.setTruststoreType(configsMap.get(Configuration.CLIENT_API_SSL_KSTR_TYPE.getKey()));
-      sapiConnector.setMaxIdleTime(configs.getConnectionMaxIdleTime());
-      apiConnector = sapiConnector;
+      contextFactoryApi.setKeyStorePath(httpsKeystore);
+      contextFactoryApi.setTrustStorePath(httpsTruststore);
+      contextFactoryApi.setKeyStorePassword(httpsCrtPass);
+      contextFactoryApi.setKeyManagerPassword(httpsCrtPass);
+      contextFactoryApi.setTrustStorePassword(httpsCrtPass);
+      contextFactoryApi.setKeyStoreType(configsMap.get(Configuration.CLIENT_API_SSL_KSTR_TYPE.getKey()));
+      contextFactoryApi.setTrustStoreType(configsMap.get(Configuration.CLIENT_API_SSL_KSTR_TYPE.getKey()));
+      apiConnector = new ServerConnector(server, acceptors, -1,
+        new SslConnectionFactory(contextFactoryApi, HttpVersion.HTTP_1_1.toString()),
+        new HttpConnectionFactory(https_config));
+      apiConnector.setPort(configs.getClientSSLApiPort());
     } else  {
-      apiConnector = new SelectChannelConnector();
+      apiConnector = new ServerConnector(server, acceptors, -1, new HttpConnectionFactory(http_config));
       apiConnector.setPort(configs.getClientApiPort());
-      apiConnector.setMaxIdleTime(configs.getConnectionMaxIdleTime());
     }
-
-    apiConnector.setRequestHeaderSize(configs.getHttpRequestHeaderSize());
-    apiConnector.setResponseHeaderSize(configs.getHttpResponseHeaderSize());
+    apiConnector.setIdleTimeout(configs.getConnectionMaxIdleTime());
 
     return apiConnector;
   }
@@ -734,9 +761,6 @@ public class AmbariServer {
    * log a warning and increase the pool size to ensure that there are at least
    * 20 available threads for requests.
    *
-   * @param server
-   *          the Jetty server instance which will have the threadpool set on it
-   *          (not {@code null}).
    * @param acceptorThreads
    *          the number of Acceptor threads configured for the connector.
    * @param threadPoolName
@@ -744,7 +768,7 @@ public class AmbariServer {
    * @param configuredThreadPoolSize
    *          the size of the pool from {@link Configuration}.
    */
-  protected void configureJettyThreadPool(Server server, int acceptorThreads,
+  protected Server configureJettyThreadPool(int acceptorThreads,
       String threadPoolName, int configuredThreadPoolSize) {
     int minumumAvailableThreads = 20;
 
@@ -770,7 +794,7 @@ public class AmbariServer {
 
     QueuedThreadPool qtp = new QueuedThreadPool(configuredThreadPoolSize);
     qtp.setName(threadPoolName);
-    server.setThreadPool(qtp);
+    return new Server(qtp);
   }
 
   /**
@@ -778,9 +802,9 @@ public class AmbariServer {
    * at server properties)
    */
   private void disableInsecureProtocols(SslContextFactory factory) {
-    // by default all protocols should be available
-    factory.setExcludeProtocols();
-    factory.setIncludeProtocols(new String[] {"SSLv2Hello","SSLv3","TLSv1","TLSv1.1","TLSv1.2"});
+    // by default all protocols should be available, excluding TLSv1.0
+    factory.setExcludeProtocols(DEPRECATED_SSL_PROTOCOLS);
+    factory.setIncludeProtocols(new String[] {"SSLv2Hello","SSLv3","TLSv1.1","TLSv1.2"});
 
     if (!configs.getSrvrDisabledCiphers().isEmpty()) {
       String[] masks = configs.getSrvrDisabledCiphers().split(DISABLED_ENTRIES_SPLITTER);
@@ -802,7 +826,11 @@ public class AmbariServer {
     configureHandlerCompression(root);
     configureAdditionalContentTypes(root);
     root.setContextPath(CONTEXT_PATH);
-    root.setErrorHandler(injector.getInstance(AmbariErrorHandler.class));
+
+    AmbariErrorHandler ambariErrorHandler = injector.getInstance(AmbariErrorHandler.class);
+    ambariErrorHandler.setShowStacks(configs.isServerShowErrorStacks());
+    root.setErrorHandler(ambariErrorHandler);
+
     root.setMaxFormContentSize(-1);
 
     /* Configure web app context */
@@ -823,9 +851,9 @@ public class AmbariServer {
       gzipFilter.setInitParameter("methods", "GET,POST,PUT,DELETE");
       gzipFilter.setInitParameter("excludePathPatterns", ".*(\\.woff|\\.ttf|\\.woff2|\\.eot|\\.svg)");
       gzipFilter.setInitParameter("mimeTypes",
-        "text/html,text/plain,text/xml,text/css,application/x-javascript," +
-          "application/xml,application/x-www-form-urlencoded," +
-          "application/javascript,application/json");
+          "text/html,text/plain,text/xml,text/css,application/x-javascript," +
+              "application/xml,application/x-www-form-urlencoded," +
+              "application/javascript,application/json");
       gzipFilter.setInitParameter("minGzipSize", configs.getApiGzipMinSize());
     }
   }
@@ -835,30 +863,6 @@ public class AmbariServer {
     root.getMimeTypes().addMimeMapping("ttf", "application/font-sfnt");
   }
 
-  /**
-   * Performs basic configuration of session manager with static values and values from
-   * configuration file.
-   *
-   * @param sessionManager session manager
-   */
-  protected void configureSessionManager(SessionManager sessionManager) {
-    // use AMBARISESSIONID instead of JSESSIONID to avoid conflicts with
-    // other services (like HDFS) that run on the same context but a different
-    // port
-    sessionManager.getSessionCookieConfig().setName("AMBARISESSIONID");
-
-    sessionManager.getSessionCookieConfig().setHttpOnly(true);
-    if (configs.getApiSSLAuthentication()) {
-      sessionManager.getSessionCookieConfig().setSecure(true);
-    }
-
-    // each request that does not use AMBARISESSIONID will create a new
-    // HashedSession in Jetty; these MUST be reaped after inactivity in order
-    // to prevent a memory leak
-    int sessionInactivityTimeout = configs.getHttpSessionInactiveTimeout();
-    sessionManager.setMaxInactiveInterval(sessionInactivityTimeout);
-  }
-
   /**
    * Creates default users if in-memory database is used
    */
@@ -868,8 +872,16 @@ public class AmbariServer {
       LOG.info("Database init needed - creating default data");
       Users users = injector.getInstance(Users.class);
 
-      users.createUser("admin", "admin");
-      users.createUser("user", "user");
+      UserEntity userEntity;
+
+      // Create the admin user
+      userEntity = users.createUser("admin", "admin", "admin");
+      users.addLocalAuthentication(userEntity, "admin");
+      users.grantAdminPrivilege(userEntity);
+
+      // Create a normal user
+      userEntity = users.createUser("user", "user", "user");
+      users.addLocalAuthentication(userEntity, "user");
 
       MetainfoEntity schemaVersion = new MetainfoEntity();
       schemaVersion.setMetainfoName(Configuration.SERVER_VERSION_KEY);
@@ -900,7 +912,6 @@ public class AmbariServer {
    */
   @Deprecated
   public void performStaticInjection() {
-    AgentResource.init(injector.getInstance(HeartBeatHandler.class));
     CertificateDownload.init(injector.getInstance(CertificateManager.class));
     ConnectionInfo.init(injector.getInstance(Configuration.class));
     CertificateSign.init(injector.getInstance(CertificateManager.class));
@@ -909,7 +920,7 @@ public class AmbariServer {
     KeyService.init(injector.getInstance(PersistKeyValueImpl.class));
     BootStrapResource.init(injector.getInstance(BootStrapImpl.class));
     StackAdvisorResourceProvider.init(injector.getInstance(StackAdvisorHelper.class),
-        injector.getInstance(Configuration.class));
+        injector.getInstance(Configuration.class), injector.getInstance(Clusters.class), injector.getInstance(AmbariMetaInfo.class));
     StageUtils.setGson(injector.getInstance(Gson.class));
     StageUtils.setTopologyManager(injector.getInstance(TopologyManager.class));
     StageUtils.setConfiguration(injector.getInstance(Configuration.class));
@@ -917,8 +928,8 @@ public class AmbariServer {
     StackDefinedPropertyProvider.init(injector);
     AbstractControllerResourceProvider.init(injector.getInstance(ResourceProviderFactory.class));
     BlueprintResourceProvider.init(injector.getInstance(BlueprintFactory.class),
-        injector.getInstance(BlueprintDAO.class), injector.getInstance(SecurityConfigurationFactory.class),
-        injector.getInstance(Gson.class), ambariMetaInfo);
+        injector.getInstance(BlueprintDAO.class), injector.getInstance(TopologyRequestDAO.class),
+        injector.getInstance(SecurityConfigurationFactory.class), injector.getInstance(Gson.class), ambariMetaInfo);
     StackDependencyResourceProvider.init(ambariMetaInfo);
     ClusterResourceProvider.init(injector.getInstance(TopologyManager.class),
         injector.getInstance(TopologyRequestFactoryImpl.class), injector.getInstance(SecurityConfigurationFactory
@@ -938,12 +949,25 @@ public class AmbariServer {
     ClusterPrivilegeResourceProvider.init(injector.getInstance(ClusterDAO.class));
     AmbariPrivilegeResourceProvider.init(injector.getInstance(ClusterDAO.class));
     ActionManager.setTopologyManager(injector.getInstance(TopologyManager.class));
+    KerberosKeytabController.setKerberosHelper(injector.getInstance(KerberosHelper.class));
     StackAdvisorBlueprintProcessor.init(injector.getInstance(StackAdvisorHelper.class));
     ThreadPoolEnabledPropertyProvider.init(injector.getInstance(Configuration.class));
 
     BaseService.init(injector.getInstance(RequestAuditLogger.class));
 
     RetryHelper.init(injector.getInstance(Clusters.class), configs.getOperationsRetryAttempts());
+
+    KerberosIdentityCleaner identityCleaner = injector.getInstance(KerberosIdentityCleaner.class);
+    identityCleaner.register();
+
+    configureFileWatcher();
+  }
+
+  private void configureFileWatcher() {
+    AmbariEventPublisher ambariEventPublisher = injector.getInstance(AmbariEventPublisher.class);
+    Configuration config = injector.getInstance(Configuration.class);
+    SingleFileWatch watch = new SingleFileWatch(config.getConfigFile(), file -> ambariEventPublisher.publish(new AmbariPropertiesChangedEvent()));
+    watch.start();
   }
 
   /**
@@ -979,6 +1003,23 @@ public class AmbariServer {
     }
   }
 
+  /**
+   * Logs startup properties.
+   */
+  private static void logStartup() {
+    final String linePrefix = "STARTUP_MESSAGE: ";
+
+    final String classpathPropertyName = "java.class.path";
+    final String classpath = System.getProperty(classpathPropertyName);
+
+    String[] rawMessages = {
+      linePrefix + "Starting AmbariServer.java executable",
+      classpathPropertyName + " = " + classpath
+    };
+
+    LOG.info(Joiner.on("\n" + linePrefix).join(rawMessages));
+  }
+
   /**
    * To change log level without restart.
    */
@@ -1042,7 +1083,8 @@ public class AmbariServer {
   }
 
   public static void main(String[] args) throws Exception {
-    Injector injector = Guice.createInjector(new ControllerModule(), new AuditLoggerModule());
+    logStartup();
+    Injector injector = Guice.createInjector(new ControllerModule(), new AuditLoggerModule(), new LdapModule());
 
     AmbariServer server = null;
     try {
@@ -1050,6 +1092,7 @@ public class AmbariServer {
 
       // check if this instance is the active instance
       Configuration config = injector.getInstance(Configuration.class);
+      config.validatePasswordPolicyRegexp();
       if (!config.isActiveInstance()) {
         String errMsg = "This instance of ambari server is not designated as active. Cannot start ambari server." +
                             "The property active.instance is set to false in ambari.properties";
@@ -1058,7 +1101,9 @@ public class AmbariServer {
 
       setupProxyAuth();
 
-      injector.getInstance(GuiceJpaInitializer.class);
+      // Start and Initialize JPA
+      GuiceJpaInitializer jpaInitializer = injector.getInstance(GuiceJpaInitializer.class);
+      jpaInitializer.setInitialized(injector.getInstance(AmbariEventPublisher.class)); // This must be called to alert Ambari that JPA is initialized.
 
       DatabaseConsistencyCheckHelper.checkDBVersionCompatible();
 
