@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -23,8 +23,8 @@ import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.Map.Entry;
+import java.util.Set;
 import java.util.regex.Pattern;
 
 import org.apache.ambari.server.AmbariException;
@@ -35,7 +35,17 @@ import org.apache.ambari.server.controller.ConfigurationRequest;
 import org.apache.ambari.server.controller.RequestStatusResponse;
 import org.apache.ambari.server.controller.predicate.ArrayPredicate;
 import org.apache.ambari.server.controller.predicate.EqualsPredicate;
-import org.apache.ambari.server.controller.spi.*;
+import org.apache.ambari.server.controller.spi.NoSuchParentResourceException;
+import org.apache.ambari.server.controller.spi.NoSuchResourceException;
+import org.apache.ambari.server.controller.spi.Predicate;
+import org.apache.ambari.server.controller.spi.Request;
+import org.apache.ambari.server.controller.spi.RequestStatus;
+import org.apache.ambari.server.controller.spi.RequestStatusMetaData;
+import org.apache.ambari.server.controller.spi.Resource;
+import org.apache.ambari.server.controller.spi.ResourceAlreadyExistsException;
+import org.apache.ambari.server.controller.spi.ResourceProvider;
+import org.apache.ambari.server.controller.spi.SystemException;
+import org.apache.ambari.server.controller.spi.UnsupportedPropertyException;
 import org.apache.ambari.server.controller.utilities.PredicateHelper;
 import org.apache.ambari.server.controller.utilities.PropertyHelper;
 import org.apache.ambari.server.security.authorization.AuthorizationException;
@@ -56,9 +66,9 @@ public abstract class AbstractResourceProvider extends BaseProvider implements R
   /**
    * Observers of this observable resource provider.
    */
-  private final Set<ResourceProviderObserver> observers = new HashSet<ResourceProviderObserver>();
+  private final Set<ResourceProviderObserver> observers = new HashSet<>();
 
-  protected final static Logger LOG = LoggerFactory.getLogger(AbstractResourceProvider.class);
+  private static final Logger LOG = LoggerFactory.getLogger(AbstractResourceProvider.class);
   protected final static String PROPERTIES_ATTRIBUTES_REGEX = "properties_attributes/[a-zA-Z][a-zA-Z._-]*$";
   public static Pattern propertiesAttributesPattern = Pattern.compile(".*/" + PROPERTIES_ATTRIBUTES_REGEX);
 
@@ -158,7 +168,7 @@ public abstract class AbstractResourceProvider extends BaseProvider implements R
     PredicateHelper.visit(givenPredicate, visitor);
     List<Predicate> predicates = visitor.getSimplifiedPredicates();
 
-    Set<Map<String, Object>> propertyMaps = new HashSet<Map<String, Object>>();
+    Set<Map<String, Object>> propertyMaps = new HashSet<>();
 
     for (Predicate predicate : predicates) {
       propertyMaps.add(PredicateHelper.getProperties(predicate));
@@ -180,18 +190,18 @@ public abstract class AbstractResourceProvider extends BaseProvider implements R
   protected Set<Map<String, Object>> getPropertyMaps(Map<String, Object> requestPropertyMap, Predicate givenPredicate)
       throws UnsupportedPropertyException, SystemException, NoSuchResourceException, NoSuchParentResourceException {
 
-    Set<Map<String, Object>> propertyMaps = new HashSet<Map<String, Object>>();
+    Set<Map<String, Object>> propertyMaps = new HashSet<>();
 
     // If the predicate specifies a unique resource then we can simply return a single
     // property map for the update.  Otherwise we need to do a get with the given predicate
     // to get the set of property maps for the resources that need to be updated.
     if (specifiesUniqueResource(givenPredicate)) {
-      Map<String, Object> propertyMap = new HashMap<String, Object>(PredicateHelper.getProperties(givenPredicate));
+      Map<String, Object> propertyMap = new HashMap<>(PredicateHelper.getProperties(givenPredicate));
       propertyMap.putAll(requestPropertyMap);
       propertyMaps.add(propertyMap);
     } else {
       for (Resource resource : getResources(givenPredicate)) {
-        Map<String, Object> propertyMap = new HashMap<String, Object>(PropertyHelper.getProperties(resource));
+        Map<String, Object> propertyMap = new HashMap<>(PropertyHelper.getProperties(resource));
         propertyMap.putAll(requestPropertyMap);
         propertyMaps.add(propertyMap);
       }
@@ -354,7 +364,7 @@ public abstract class AbstractResourceProvider extends BaseProvider implements R
    */
   public static List<ConfigurationRequest> getConfigurationRequests(String parentCategory, Map<String, Object> properties) {
 
-    List<ConfigurationRequest> configs = new LinkedList<ConfigurationRequest>();
+    List<ConfigurationRequest> configs = new LinkedList<>();
 
     String desiredConfigKey = parentCategory + "/desired_config";
     // Multiple configs to be updated
@@ -416,12 +426,12 @@ public abstract class AbstractResourceProvider extends BaseProvider implements R
       String attributeName = absCategory.substring(absCategory.lastIndexOf('/') + 1);
       Map<String, Map<String, String>> configAttributesMap = config.getPropertiesAttributes();
       if (null == configAttributesMap) {
-        configAttributesMap = new HashMap<String, Map<String,String>>();
+        configAttributesMap = new HashMap<>();
         config.setPropertiesAttributes(configAttributesMap);
       }
       Map<String, String> attributesMap = configAttributesMap.get(attributeName);
       if (null == attributesMap) {
-        attributesMap = new HashMap<String, String>();
+        attributesMap = new HashMap<>();
         configAttributesMap.put(attributeName, attributesMap);
       }
       attributesMap.put(propName, propValue);
@@ -490,6 +500,6 @@ public abstract class AbstractResourceProvider extends BaseProvider implements R
      *
      * @throws AmbariException thrown if a problem occurred during invocation
      */
-    public T invoke() throws AmbariException, AuthorizationException;
+    T invoke() throws AmbariException, AuthorizationException;
   }
 }
