@@ -53,6 +53,8 @@ import org.apache.ambari.server.state.AlertState;
 import org.apache.ambari.server.state.alert.AlertGroup;
 import org.apache.ambari.server.state.alert.AlertTarget;
 import org.apache.commons.lang.StringUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.gson.Gson;
 import com.google.inject.Inject;
@@ -67,16 +69,29 @@ import com.google.inject.persist.Transactional;
 public class AlertTargetResourceProvider extends
  AbstractAuthorizedResourceProvider {
 
+  private static final Logger LOG = LoggerFactory.getLogger(AlertTargetResourceProvider.class);
+    
   public static final String ALERT_TARGET = "AlertTarget";
-  public static final String ALERT_TARGET_ID = "AlertTarget/id";
-  public static final String ALERT_TARGET_NAME = "AlertTarget/name";
-  public static final String ALERT_TARGET_DESCRIPTION = "AlertTarget/description";
-  public static final String ALERT_TARGET_NOTIFICATION_TYPE = "AlertTarget/notification_type";
-  public static final String ALERT_TARGET_PROPERTIES = "AlertTarget/properties";
-  public static final String ALERT_TARGET_GROUPS = "AlertTarget/groups";
-  public static final String ALERT_TARGET_STATES = "AlertTarget/alert_states";
-  public static final String ALERT_TARGET_GLOBAL = "AlertTarget/global";
-  public static final String ALERT_TARGET_ENABLED = "AlertTarget/enabled";
+
+  public static final String ID_PROPERTY_ID = "id";
+  public static final String NAME_PROPERTY_ID = "name";
+  public static final String DESCRIPTION_PROPERTY_ID = "description";
+  public static final String NOTIFICATION_TYPE_PROPERTY_ID = "notification_type";
+  public static final String PROPERTIES_PROPERTY_ID = "properties";
+  public static final String GROUPS_PROPERTY_ID = "groups";
+  public static final String STATES_PROPERTY_ID = "alert_states";
+  public static final String GLOBAL_PROPERTY_ID = "global";
+  public static final String ENABLED_PROPERTY_ID = "enabled";
+
+  public static final String ALERT_TARGET_ID = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + ID_PROPERTY_ID;
+  public static final String ALERT_TARGET_NAME = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + NAME_PROPERTY_ID;
+  public static final String ALERT_TARGET_DESCRIPTION = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + DESCRIPTION_PROPERTY_ID;
+  public static final String ALERT_TARGET_NOTIFICATION_TYPE = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + NOTIFICATION_TYPE_PROPERTY_ID;
+  public static final String ALERT_TARGET_PROPERTIES = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + PROPERTIES_PROPERTY_ID;
+  public static final String ALERT_TARGET_GROUPS = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + GROUPS_PROPERTY_ID;
+  public static final String ALERT_TARGET_STATES = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + STATES_PROPERTY_ID;
+  public static final String ALERT_TARGET_GLOBAL = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + GLOBAL_PROPERTY_ID;
+  public static final String ALERT_TARGET_ENABLED = ALERT_TARGET + PropertyHelper.EXTERNAL_PATH_SEP + ENABLED_PROPERTY_ID;
 
   private static final Set<String> PK_PROPERTY_IDS = new HashSet<>(
       Arrays.asList(ALERT_TARGET_ID, ALERT_TARGET_NAME));
@@ -126,7 +141,7 @@ public class AlertTargetResourceProvider extends
    */
   @Inject
   AlertTargetResourceProvider() {
-    super(PROPERTY_IDS, KEY_PROPERTY_IDS);
+    super(Resource.Type.AlertTarget, PROPERTY_IDS, KEY_PROPERTY_IDS);
 
     EnumSet<RoleAuthorization> requiredAuthorizations = EnumSet.of(RoleAuthorization.CLUSTER_MANAGE_ALERT_NOTIFICATIONS);
     setRequiredCreateAuthorizations(requiredAuthorizations);
@@ -320,13 +335,15 @@ public class AlertTargetResourceProvider extends
       }
 
       // if we are overwriting an existing, determine if one exists first
-      AlertTargetEntity entity = null;
-      if( overwriteExisting ) {
-        entity = s_dao.findTargetByName(name);
-      }
+      AlertTargetEntity entity = s_dao.findTargetByName(name);
 
       if (null == entity) {
         entity = new AlertTargetEntity();
+      } else {
+        if( !overwriteExisting ) {
+          throw new IllegalArgumentException(
+              "Alert targets already exists and can't be created");
+        }
       }
 
       // groups are not required on creation
@@ -488,7 +505,7 @@ public class AlertTargetResourceProvider extends
     if (BaseProvider.isPropertyRequested(ALERT_TARGET_GROUPS, requestedIds)) {
       Set<AlertGroupEntity> groupEntities = entity.getAlertGroups();
       List<AlertGroup> groups = new ArrayList<>(
-          groupEntities.size());
+        groupEntities.size());
 
       for (AlertGroupEntity groupEntity : groupEntities) {
         AlertGroup group = new AlertGroup();
@@ -517,7 +534,7 @@ public class AlertTargetResourceProvider extends
    */
   private Map<String, Object> extractProperties(Map<String, Object> requestMap) {
     Map<String, Object> normalizedMap = new HashMap<>(
-        requestMap.size());
+      requestMap.size());
 
     for (Entry<String, Object> entry : requestMap.entrySet()) {
       String key = entry.getKey();
