@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -358,7 +358,7 @@ public class AlertsDAO implements Cleanable {
     }
 
     // sorting
-    JpaSortBuilder<AlertHistoryEntity> sortBuilder = new JpaSortBuilder<AlertHistoryEntity>();
+    JpaSortBuilder<AlertHistoryEntity> sortBuilder = new JpaSortBuilder<>();
     List<Order> sortOrders = sortBuilder.buildSortOrders(request.Sort, visitor);
     query.orderBy(sortOrders);
 
@@ -396,7 +396,7 @@ public class AlertsDAO implements Cleanable {
     }
 
     // sorting
-    JpaSortBuilder<AlertCurrentEntity> sortBuilder = new JpaSortBuilder<AlertCurrentEntity>();
+    JpaSortBuilder<AlertCurrentEntity> sortBuilder = new JpaSortBuilder<>();
     List<Order> sortOrders = sortBuilder.buildSortOrders(request.Sort, visitor);
     query.orderBy(sortOrders);
 
@@ -587,7 +587,7 @@ public class AlertsDAO implements Cleanable {
     query.setParameter("unknownState", AlertState.UNKNOWN);
     query.setParameter("maintenanceStateOff", MaintenanceState.OFF);
 
-    Map<String, AlertSummaryDTO> map = new HashMap<String, AlertSummaryDTO>();
+    Map<String, AlertSummaryDTO> map = new HashMap<>();
     List<HostAlertSummaryDTO> resultList = m_daoUtils.selectList(query);
     for (HostAlertSummaryDTO result : resultList) {
       map.put(result.getHostName(), result);
@@ -985,8 +985,18 @@ public class AlertsDAO implements Cleanable {
    *          the alert to merge (not {@code null}).
    * @return the updated alert with merged content (never {@code null}).
    */
-  @Transactional
   public AlertHistoryEntity merge(AlertHistoryEntity alert) {
+    if (m_configuration.isAlertCacheEnabled()) {
+      synchronized (this) {
+        return mergeTransactional(alert);
+      }
+    } else {
+      return mergeTransactional(alert);
+    }
+  }
+
+  @Transactional
+  protected AlertHistoryEntity mergeTransactional(AlertHistoryEntity alert) {
     return m_entityManagerProvider.get().merge(alert);
   }
 
@@ -1033,8 +1043,18 @@ public class AlertsDAO implements Cleanable {
    *          the current alert to merge (not {@code null}).
    * @return the updated current alert with merged content (never {@code null}).
    */
-  @Transactional
   public AlertCurrentEntity merge(AlertCurrentEntity alert) {
+    if (m_configuration.isAlertCacheEnabled()) {
+      synchronized (this) {
+        return mergeTransactional(alert);
+      }
+    } else {
+      return mergeTransactional(alert);
+    }
+  }
+
+  @Transactional
+  protected AlertCurrentEntity mergeTransactional(AlertCurrentEntity alert) {
     // perform the JPA merge
     alert = m_entityManagerProvider.get().merge(alert);
 
@@ -1174,12 +1194,18 @@ public class AlertsDAO implements Cleanable {
    * Writes all cached {@link AlertCurrentEntity} instances to the database and
    * clears the cache.
    */
-  @Transactional
   public void flushCachedEntitiesToJPA() {
-    if (!m_configuration.isAlertCacheEnabled()) {
+    if (m_configuration.isAlertCacheEnabled()) {
+      synchronized (this) {
+        flushCachedEntitiesToJPATransactional();
+      }
+    } else {
       LOG.warn("Unable to flush cached alerts to JPA because caching is not enabled");
-      return;
     }
+  }
+
+  @Transactional
+  protected void flushCachedEntitiesToJPATransactional() {
 
     // capture for logging purposes
     long cachedEntityCount = m_currentAlertCache.size();
@@ -1212,6 +1238,10 @@ public class AlertsDAO implements Cleanable {
       AlertCacheKey key = AlertCacheKey.build(alert);
       AlertCurrentEntity cachedEntity = m_currentAlertCache.getIfPresent(key);
       if (null != cachedEntity) {
+        if (cachedEntity.getAlertHistory() == null) {
+          LOG.warn("There is current entity with null history in the cache, currentId: {}, persisted historyId: {}",
+              cachedEntity.getAlertId(), alert.getHistoryId());
+        }
         alert = cachedEntity;
       }
 
@@ -1584,4 +1614,41 @@ public class AlertsDAO implements Cleanable {
     return affectedRows;
   }
 
+  /**
+   * Saves alert and alert history entities in single transaction
+   * @param toMerge - merge alert only
+   * @param toCreateHistoryAndMerge - create new history, merge alert
+   */
+  public void saveEntities(List<AlertCurrentEntity> toMerge,
+                                 List<AlertCurrentEntity> toCreateHistoryAndMerge) {
+    if (m_configuration.isAlertCacheEnabled()) {
+      synchronized (this) {
+        saveEntitiesTransactional(toMerge, toCreateHistoryAndMerge);
+      }
+    } else {
+      saveEntitiesTransactional(toMerge, toCreateHistoryAndMerge);
+    }
+  }
+
+  @Transactional
+  protected void saveEntitiesTransactional(List<AlertCurrentEntity> toMerge,
+                    List<AlertCurrentEntity> toCreateHistoryAndMerge) {
+    for (AlertCurrentEntity entity : toMerge) {
+      merge(entity, m_configuration.isAlertCacheEnabled());
+    }
+
+    for (AlertCurrentEntity entity : toCreateHistoryAndMerge) {
+      create(entity.getAlertHistory());
+      merge(entity);
+
+      if (LOG.isDebugEnabled()) {
+        LOG.debug(
+            "Alert State Merged: CurrentId {}, CurrentTimestamp {}, HistoryId {}, HistoryState {}",
+            entity.getAlertId(), entity.getLatestTimestamp(),
+            entity.getAlertHistory().getAlertId(),
+            entity.getAlertHistory().getAlertState());
+      }
+    }
+  }
+
 }
