@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,6 +18,6 @@
 package org.apache.ambari.server.security.encryption;
 
 public interface MasterKeyService {
-  public char[] getMasterSecret();
-  public boolean isMasterKeyInitialized();
+  char[] getMasterSecret();
+  boolean isMasterKeyInitialized();
 }
