@@ -18,26 +18,44 @@
 
 package org.apache.ambari.server.serveraction.kerberos;
 
-import com.google.inject.Inject;
+import java.io.File;
+import java.io.IOException;
+import java.lang.reflect.Type;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Set;
+import java.util.concurrent.Callable;
+import java.util.stream.Collectors;
+
 import org.apache.ambari.server.AmbariException;
+import org.apache.ambari.server.AmbariRuntimeException;
 import org.apache.ambari.server.actionmanager.HostRoleStatus;
 import org.apache.ambari.server.agent.CommandReport;
 import org.apache.ambari.server.agent.ExecutionCommand;
+import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.KerberosHelper;
+import org.apache.ambari.server.controller.UpdateConfigurationPolicy;
+import org.apache.ambari.server.orm.dao.HostDAO;
+import org.apache.ambari.server.orm.entities.HostEntity;
 import org.apache.ambari.server.security.credential.PrincipalKeyCredential;
 import org.apache.ambari.server.serveraction.AbstractServerAction;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.KerberosKeytabController;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.ResolvedKerberosPrincipal;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
+import org.apache.ambari.server.state.Config;
+import org.apache.ambari.server.state.kerberos.KerberosIdentityDescriptor;
 import org.apache.ambari.server.utils.StageUtils;
+import org.apache.ambari.server.utils.ThreadPools;
+import org.apache.commons.io.FileUtils;
+import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import static org.apache.ambari.server.serveraction.kerberos.KerberosIdentityDataFileReader.DATA_FILE_NAME;
-
-import java.io.File;
-import java.io.IOException;
-import java.util.HashMap;
-import java.util.Map;
+import com.google.common.reflect.TypeToken;
+import com.google.inject.Inject;
 
 /**
  * KerberosServerAction is an abstract class to be implemented by Kerberos-related
@@ -88,10 +106,20 @@ public abstract class KerberosServerAction extends AbstractServerAction {
   public static final String KDC_TYPE = "kdc_type";
 
   /**
-   * A (command parameter) property name used to hold a boolean value indicating whether configurations
-   * should be process to see if they need to be updated
+   * A (command parameter) property name used to hold the value indicating how to process
+   * configurations updates. One of the of the following values is expected:
+   * <dl>
+   * <dt>none</dt>
+   * <dd>No configurations will be updated</dd>
+   * <dt>identities_only</dt>
+   * <dd>New and updated configurations related to Kerberos identity information - principal, keytab file, and auth-to-local rule properties</dd>
+   * <dt>new_and_identities</dt>
+   * <dd>Only new configurations declared by the Kerberos descriptor and stack advisor as well as the identity-related changes</dd>
+   * <dt>all</dt>
+   * <dd>All configuration changes (default)</dd>
+   * </dl>
    */
-  public static final String UPDATE_CONFIGURATIONS = "update_configurations";
+  public static final String UPDATE_CONFIGURATION_POLICY = "update_configuration_policy";
 
   /**
    * A (command parameter) property name used to hold the note to set when applying any
@@ -104,31 +132,32 @@ public abstract class KerberosServerAction extends AbstractServerAction {
    */
   public static final String DATA_DIRECTORY_PREFIX = ".ambari_";
 
-  /*
+  /**
    * Kerberos action shared data entry name for the principal-to-password map
    */
   private static final String PRINCIPAL_PASSWORD_MAP = "principal_password_map";
 
-  /*
+  /**
    * Kerberos action shared data entry name for the principal-to-key_number map
    */
   private static final String PRINCIPAL_KEY_NUMBER_MAP = "principal_key_number_map";
 
-  /*
-  * Key used in kerberosCommandParams in ExecutionCommand for base64 encoded keytab content
-  */
+  /**
+   * Key used in kerberosCommandParams in ExecutionCommand for base64 encoded keytab content
+   */
   public static final String KEYTAB_CONTENT_BASE64 = "keytab_content_base64";
 
-  /*
-  * Key used in kerberosCommandParams in ExecutionCommand to indicate whether to generate key keytabs
-  * for all principals ("true") or only those that are missing ("false")
-  */
-  public static final String REGENERATE_ALL = "regenerate_all";
+  /**
+   * Key used in kerberosCommandParams in ExecutionCommand to indicate why type of creation operation to perform.
+   *
+   * @see OperationType
+   */
+  public static final String OPERATION_TYPE = "operation_type";
 
-  /*
-  * Key used in kerberosCommandParams in ExecutionCommand to indicate whether to include Ambari server indetity
-  * ("true") or ignore it ("false")
-  */
+  /**
+   * Key used in kerberosCommandParams in ExecutionCommand to indicate whether to include Ambari server indetity
+   * ("true") or ignore it ("false")
+   */
   public static final String INCLUDE_AMBARI_IDENTITY = "include_ambari_identity";
 
   /**
@@ -153,18 +182,24 @@ public abstract class KerberosServerAction extends AbstractServerAction {
   @Inject
   private KerberosOperationHandlerFactory kerberosOperationHandlerFactory;
 
-  /**
-   * The KerberosIdentityDataFileReaderFactory to use to obtain KerberosIdentityDataFileReader instances
-   */
-  @Inject
-  private KerberosIdentityDataFileReaderFactory kerberosIdentityDataFileReaderFactory;
-
   /**
    * KerberosHelper
    */
   @Inject
   private KerberosHelper kerberosHelper;
 
+  @Inject
+  private HostDAO hostDAO;
+
+  @Inject
+  private KerberosKeytabController kerberosKeytabController;
+
+  @Inject
+  private Configuration configuration;
+
+  @Inject
+  private ThreadPools threadPools;
+
   /**
    * Given a (command parameter) Map and a property name, attempts to safely retrieve the requested
    * data.
@@ -177,6 +212,20 @@ public abstract class KerberosServerAction extends AbstractServerAction {
     return ((commandParameters == null) || (propertyName == null)) ? null : commandParameters.get(propertyName);
   }
 
+  /**
+   * Given a (command parameter) Map, attempts to safely retrieve the "update_configuration_policy" property.
+   *
+   * @param commandParameters a Map containing the dictionary of data to interrogate
+   * @return a UpdateConfigurationPolicy
+   */
+  protected static UpdateConfigurationPolicy getUpdateConfigurationPolicy(Map<String, String> commandParameters) {
+    String stringValue = getCommandParameterValue(commandParameters, UPDATE_CONFIGURATION_POLICY);
+    UpdateConfigurationPolicy value = UpdateConfigurationPolicy.translate(stringValue);
+
+    // Return UpdateConfigurationPolicy.ALL as a default value
+    return (value == null) ? UpdateConfigurationPolicy.ALL : value;
+  }
+
   /**
    * Given a (command parameter) Map, attempts to safely retrieve the "default_realm" property.
    *
@@ -214,6 +263,21 @@ public abstract class KerberosServerAction extends AbstractServerAction {
     return getCommandParameterValue(commandParameters, DATA_DIRECTORY);
   }
 
+  /**
+   * Given a (command parameter) Map, attempts to safely retrieve the "operation_type" property.
+   *
+   * @param commandParameters a Map containing the dictionary of data to interrogate
+   * @return an OperationType
+   */
+  protected static OperationType getOperationType(Map<String, String> commandParameters) {
+    String value = getCommandParameterValue(commandParameters, OPERATION_TYPE);
+    if (StringUtils.isEmpty(value)) {
+      return OperationType.DEFAULT;
+    } else {
+      return OperationType.valueOf(value.toUpperCase());
+    }
+  }
+
   /**
    * Sets the shared principal-to-password Map used to store principals and generated password for
    * use within the current request context.
@@ -240,19 +304,13 @@ public abstract class KerberosServerAction extends AbstractServerAction {
    *                                 to a given request
    * @return A Map of principals-to-password
    */
+  @SuppressWarnings("unchecked")
   protected static Map<String, String> getPrincipalPasswordMap(Map<String, Object> requestSharedDataContext) {
     if (requestSharedDataContext == null) {
       return null;
-    } else {
-      Object map = requestSharedDataContext.get(PRINCIPAL_PASSWORD_MAP);
-
-      if (map == null) {
-        map = new HashMap<String, String>();
-        requestSharedDataContext.put(PRINCIPAL_PASSWORD_MAP, map);
-      }
-
-      return (Map<String, String>) map;
-    }
+    } 
+    Object map = requestSharedDataContext.computeIfAbsent(PRINCIPAL_PASSWORD_MAP, k -> new HashMap<String, String>());
+    return (Map<String, String>) map;
   }
 
   /**
@@ -266,19 +324,13 @@ public abstract class KerberosServerAction extends AbstractServerAction {
    *                                 to a given request
    * @return A Map of principals-to-key_numbers
    */
+  @SuppressWarnings("unchecked")
   protected static Map<String, Integer> getPrincipalKeyNumberMap(Map<String, Object> requestSharedDataContext) {
     if (requestSharedDataContext == null) {
       return null;
-    } else {
-      Object map = requestSharedDataContext.get(PRINCIPAL_KEY_NUMBER_MAP);
-
-      if (map == null) {
-        map = new HashMap<String, String>();
-        requestSharedDataContext.put(PRINCIPAL_KEY_NUMBER_MAP, map);
-      }
-
-      return (Map<String, Integer>) map;
     }
+    Object map = requestSharedDataContext.computeIfAbsent(PRINCIPAL_KEY_NUMBER_MAP, k -> new HashMap<String, String>());
+    return (Map<String, Integer>) map;
   }
 
   /**
@@ -335,15 +387,36 @@ public abstract class KerberosServerAction extends AbstractServerAction {
     return getDataDirectoryPath(getCommandParameters());
   }
 
+  /**
+   * Returns preconfigure type passed to current action.
+   *
+   * @return PreconfigureServiceType
+   */
+  protected PreconfigureServiceType getCommandPreconfigureType() {
+    String preconfigureServices = getCommandParameterValue(getCommandParameters(), PRECONFIGURE_SERVICES);
+    PreconfigureServiceType type = null;
+    if (!StringUtils.isEmpty(preconfigureServices)) {
+      try {
+        type = PreconfigureServiceType.valueOf(preconfigureServices.toUpperCase());
+      } catch (Throwable t) {
+        LOG.warn("Invalid preconfigure_services value, assuming DEFAULT: {}", preconfigureServices);
+        type = PreconfigureServiceType.DEFAULT;
+      }
+    }
+    return type;
+  }
+
   /**
    * Iterates through the Kerberos identity metadata from the
    * {@link org.apache.ambari.server.serveraction.kerberos.KerberosIdentityDataFileReader} and calls
    * the implementing class to handle each identity found.
    * <p/>
-   * Using the "data_directory" value from this action's command parameters map, creates a
-   * {@link KerberosIdentityDataFileReader} to parse
-   * the relative identity.dat file and iterate through its "records".  Each "record" is process using
-   * {@link #processRecord(Map, String, KerberosOperationHandler, Map, Map)}.
+   * Using {@link #getHostFilter()}, {@link #getIdentityFilter()} and {@link #getServiceComponentFilter()} it retrieve
+   * list of filtered keytabs and their principals and process each principal using
+   * {@link #processIdentity(ResolvedKerberosPrincipal, KerberosOperationHandler, Map, boolean, Map)}.
+   * The configuration option {@link Configuration#getKerberosServerActionThreadPoolSize()} defines
+   * how many threads will handle {@link #processIdentity(ResolvedKerberosPrincipal, KerberosOperationHandler, Map, boolean, Map)}.
+   * The default is {@code 1}, but this method must be thread-safe in the event that concurrent threads are used.
    *
    * @param requestSharedDataContext a Map to be used a shared data among all ServerActions related
    *                                 to a given request
@@ -352,7 +425,7 @@ public abstract class KerberosServerAction extends AbstractServerAction {
    */
   protected CommandReport processIdentities(Map<String, Object> requestSharedDataContext)
       throws AmbariException {
-    CommandReport commandReport = null;
+    final CommandReport[] commandReport = {null};
     Map<String, String> commandParameters = getCommandParameters();
 
     actionLog.writeStdOut("Processing identities...");
@@ -361,102 +434,74 @@ public abstract class KerberosServerAction extends AbstractServerAction {
     if (commandParameters != null) {
       // Grab the relevant data from this action's command parameters map
       PrincipalKeyCredential administratorCredential = kerberosHelper.getKDCAdministratorCredentials(getClusterName());
-      String defaultRealm = getDefaultRealm(commandParameters);
       KDCType kdcType = getKDCType(commandParameters);
-      String dataDirectoryPath = getDataDirectoryPath(commandParameters);
+      String defaultRealm = getDefaultRealm(commandParameters);
 
-      if (dataDirectoryPath != null) {
-        File dataDirectory = new File(dataDirectoryPath);
+      KerberosOperationHandler handler = kerberosOperationHandlerFactory.getKerberosOperationHandler(kdcType);
+      Map<String, String> kerberosConfiguration = getConfigurationProperties("kerberos-env");
 
-        // If the data directory exists, attempt to process further, else assume there is no work to do
-        if (dataDirectory.exists()) {
-          if (!dataDirectory.isDirectory() || !dataDirectory.canRead()) {
-            String message = String.format("Failed to process the identities, the data directory is not accessible: %s",
-                dataDirectory.getAbsolutePath());
-            actionLog.writeStdErr(message);
-            LOG.error(message);
-            throw new AmbariException(message);
-          }
-          // The "identity data" file may or may not exist in the data directory, depending on if
-          // there is work to do or not.
-          File identityDataFile = new File(dataDirectory, DATA_FILE_NAME);
+      try {
+        handler.open(administratorCredential, defaultRealm, kerberosConfiguration);
+      } catch (KerberosOperationException e) {
+        String message = String.format("Failed to process the identities, could not properly open the KDC operation handler: %s",
+            e.getMessage());
+        actionLog.writeStdErr(message);
+        LOG.error(message);
+        throw new AmbariException(message, e);
+      }
 
-          if (identityDataFile.exists()) {
-            if (!identityDataFile.canRead()) {
-              String message = String.format("Failed to process the identities, cannot read the index file: %s",
-                  identityDataFile.getAbsolutePath());
-              actionLog.writeStdErr(message);
-              LOG.error(message);
-              throw new AmbariException(message);
-            }
+      try {
+        // create the thread factory, executor, and completion service for
+        // running the identity processing in parallel
 
-            KerberosOperationHandler handler = kerberosOperationHandlerFactory.getKerberosOperationHandler(kdcType);
-            if (handler == null) {
-              String message = String.format("Failed to process the identities, a KDC operation handler was not found for the KDC type of : %s",
-                  kdcType.toString());
-              actionLog.writeStdErr(message);
-              LOG.error(message);
-              throw new AmbariException(message);
-            }
+        ExecutionCommand executionCommand = getExecutionCommand();
+        int threadCount = configuration.getKerberosServerActionThreadPoolSize();
+        String factoryName = (executionCommand == null)
+          ? "process-identity-%d"
+          : "process-identity-task-" + executionCommand.getTaskId() + "-thread-%d";
 
-            Map<String, String> kerberosConfiguration = getConfiguration("kerberos-env");
 
-            try {
-              handler.open(administratorCredential, defaultRealm, kerberosConfiguration);
-            } catch (KerberosOperationException e) {
-              String message = String.format("Failed to process the identities, could not properly open the KDC operation handler: %s",
-                  e.getMessage());
-              actionLog.writeStdErr(message);
-              LOG.error(message);
-              throw new AmbariException(message, e);
-            }
+        Map<String, Collection<String>> serviceComponentFilter = getServiceComponentFilter();
+        if (serviceComponentFilter != null && pruneServiceFilter()) {
+          kerberosKeytabController.adjustServiceComponentFilter(clusters.getCluster(getClusterName()),
+            true, serviceComponentFilter);
+        }
+        final Collection<KerberosIdentityDescriptor> serviceIdentities = (serviceComponentFilter == null)
+          ? null
+          : kerberosKeytabController.getServiceIdentities(getClusterName(), serviceComponentFilter.keySet(), null);
 
-            // Create the data file reader to parse and iterate through the records
-            KerberosIdentityDataFileReader reader = null;
-            try {
-              reader = kerberosIdentityDataFileReaderFactory.createKerberosIdentityDataFileReader(identityDataFile);
-              for (Map<String, String> record : reader) {
-                // Process the current record
-                commandReport = processRecord(record, defaultRealm, handler, kerberosConfiguration, requestSharedDataContext);
-
-                // If the principal processor returns a CommandReport, than it is time to stop since
-                // an error condition has probably occurred, else all is assumed to be well.
-                if (commandReport != null) {
-                  break;
-                }
-              }
-            } catch (AmbariException e) {
-              // Catch this separately from IOException since the reason it was thrown was not the same
-              // Note: AmbariException is an IOException, so there may be some confusion
-              throw new AmbariException(e.getMessage(), e);
-            } catch (IOException e) {
-              String message = String.format("Failed to process the identities, cannot read the index file: %s",
-                  identityDataFile.getAbsolutePath());
-              actionLog.writeStdErr(message);
-              LOG.error(message, e);
-              throw new AmbariException(message, e);
-            } finally {
-              if (reader != null) {
-                // The reader needs to be closed, if it fails to close ignore the exception since
-                // there is little we can or care to do about it now.
-                try {
-                  reader.close();
-                } catch (IOException e) {
-                  // Ignore this...
-                }
-              }
-
-              // The KerberosOperationHandler needs to be closed, if it fails to close ignore the
-              // exception since there is little we can or care to do about it now.
+        threadPools.parallelOperation(factoryName, threadCount, "identities",
+          kerberosKeytabController.getFilteredKeytabs(serviceIdentities, getHostFilter(), getIdentityFilter())
+            .stream().flatMap(rkk -> rkk.getPrincipals().stream()).map(principal -> (Callable<CommandReport>) () -> {
               try {
-                handler.close();
-              } catch (KerberosOperationException e) {
-                // Ignore this...
+                return processIdentity(principal, handler, kerberosConfiguration,
+                  isRelevantIdentity(serviceIdentities, principal), requestSharedDataContext);
+              } catch (AmbariException ambariException) {
+                throw new AmbariRuntimeException(ambariException);
               }
             }
+          ).collect(Collectors.toList()),
+          (cr) -> { // processIdentity returns null if operation completed ok, else FAILED report generated
+            boolean isFailed = Objects.isNull(cr);
+            if (!isFailed) {
+              commandReport[0] = cr;
+            }
+            return isFailed;
           }
+        );
+      } catch (Exception exception) {
+        LOG.error("Unable to process identities asynchronously", exception);
+        return createCommandReport(0, HostRoleStatus.FAILED, "{}", actionLog.getStdOut(), actionLog.getStdErr());
+      } finally {
+        // The KerberosOperationHandler needs to be closed, if it fails to close ignore the
+        // exception since there is little we can or care to do about it now.
+        try {
+          handler.close();
+        } catch (KerberosOperationException e) {
+          // Ignore this...
         }
       }
+
     }
 
     actionLog.writeStdOut("Processing identities completed.");
@@ -464,81 +509,240 @@ public abstract class KerberosServerAction extends AbstractServerAction {
 
     // If commandReport is null, we can assume this operation was a success, so return a successful
     // CommandReport; else return the previously created CommandReport.
-    return (commandReport == null)
+    return (commandReport[0] == null)
         ? createCommandReport(0, HostRoleStatus.COMPLETED, "{}", actionLog.getStdOut(), actionLog.getStdErr())
-        : commandReport;
+        : commandReport[0];
+  }
+
+  protected boolean pruneServiceFilter() {
+    return true;
+  }
+
+  private boolean isRelevantIdentity(Collection<KerberosIdentityDescriptor> serviceIdentities, ResolvedKerberosPrincipal principal) {
+    if (serviceIdentities != null) {
+      boolean hasValidIdentity = false;
+      for (KerberosIdentityDescriptor serviceIdentity : serviceIdentities) {
+        if (principal.getPrincipal().equals(serviceIdentity.getPrincipalDescriptor().getName()) && StringUtils.isBlank(serviceIdentity.getReference())) {
+          hasValidIdentity = true;
+          break;
+        }
+      }
+      return hasValidIdentity;
+    }
+
+    return true;
   }
 
   /**
    * Processes an identity as necessary.
    * <p/>
    * This method is called from {@link #processIdentities(Map)} for each
-   * identity "record" found in the Kerberos identity metadata file. After processing, it is expected
+   * principal found by specified filter. After processing, it is expected
    * that the return value is null on success and a CommandReport (indicating the error) on failure.
    *
-   * @param identityRecord           a Map containing the data for the current identity record
-   * @param evaluatedPrincipal       a String indicating the relevant principal
+   * @param resolvedPrincipal        a ResolvedKerberosPrincipal object to process
    * @param operationHandler         a KerberosOperationHandler used to perform Kerberos-related
    *                                 tasks for specific Kerberos implementations
    *                                 (MIT, Active Directory, etc...)
    * @param kerberosConfiguration    a Map of configuration properties from kerberos-env
+   * @param includedInFilter         a Boolean value indicating whather the principal is included in
+   *                                 the current filter or not
    * @param requestSharedDataContext a Map to be used a shared data among all ServerActions related
    *                                 to a given request  @return a CommandReport, indicating an error
    *                                 condition; or null, indicating a success condition
    * @throws AmbariException if an error occurs while processing the identity record
    */
-  protected abstract CommandReport processIdentity(Map<String, String> identityRecord,
-                                                   String evaluatedPrincipal,
+  protected abstract CommandReport processIdentity(ResolvedKerberosPrincipal resolvedPrincipal,
                                                    KerberosOperationHandler operationHandler,
                                                    Map<String, String> kerberosConfiguration,
+                                                   boolean includedInFilter,
                                                    Map<String, Object> requestSharedDataContext)
       throws AmbariException;
 
-  /**
-   * Process and prepares an identity record to be handled by the implementing class.
-   * <p/>
-   * Given the data from the record Map, attempts to replace variables in the principal pattern to
-   * generate a concrete principal value to further process. This "evaluated principal" is then passed to
-   * {@link #processIdentity(Map, String, KerberosOperationHandler, Map, Map)}
-   * to be handled as needed.
-   *
-   * @param record                   a Map containing the data for the current identity record
-   * @param defaultRealm             a String declaring the default Kerberos realm
-   * @param operationHandler         a KerberosOperationHandler used to perform Kerberos-related
-   *                                 tasks for specific Kerberos implementations
-   *                                 (MIT, Active Directory, etc...)
-   * @param kerberosConfiguration    a Map of configuration properties from kerberos-env
-   * @param requestSharedDataContext a Map to be used a shared data among all ServerActions related
-   *                                 to a given request  @return a CommandReport, indicating an error
-   *                                 condition; or null, indicating a success condition
-   * @throws AmbariException if an error occurs while processing the identity record
-   */
-  private CommandReport processRecord(Map<String, String> record, String defaultRealm,
-                                      KerberosOperationHandler operationHandler,
-                                      Map<String, String> kerberosConfiguration, Map<String, Object> requestSharedDataContext)
-      throws AmbariException {
-    CommandReport commandReport = null;
+  protected void deleteDataDirectory(String dataDirectoryPath) {
+    // Make sure this is a relevant directory. We don't want to accidentally allow _ANY_ directory
+    // to be deleted.
+    if ((dataDirectoryPath != null) && dataDirectoryPath.contains("/" + DATA_DIRECTORY_PREFIX)) {
+      File dataDirectory = new File(dataDirectoryPath);
+      File dataDirectoryParent = dataDirectory.getParentFile();
 
-    if (record != null) {
-      String principal = record.get(KerberosIdentityDataFileReader.PRINCIPAL);
-
-      if (principal != null) {
-        String hostname = record.get(KerberosIdentityDataFileReader.HOSTNAME);
-
-        if(KerberosHelper.AMBARI_SERVER_HOST_NAME.equals(hostname)) {
-          // Replace KerberosHelper.AMBARI_SERVER_HOST_NAME with the actual hostname where the Ambari
-          // server is... this host
-          hostname = StageUtils.getHostName();
+      // Make sure this directory has a parent and it is writeable, else we wont be able to
+      // delete the directory
+      if ((dataDirectoryParent != null) && dataDirectory.isDirectory() &&
+          dataDirectoryParent.isDirectory() && dataDirectoryParent.canWrite()) {
+        try {
+          FileUtils.deleteDirectory(dataDirectory);
+        } catch (IOException e) {
+          // We should log this exception, but don't let it fail the process since if we got to this
+          // KerberosServerAction it is expected that the the overall process was a success.
+          String message = String.format("The data directory (%s) was not deleted due to an error condition - {%s}",
+              dataDirectory.getAbsolutePath(), e.getMessage());
+          LOG.warn(message, e);
         }
+      }
+    }
+  }
 
-        // Evaluate the principal "pattern" found in the record to generate the "evaluated principal"
-        // by replacing the _HOST and _REALM variables.
-        String evaluatedPrincipal = principal.replace("_HOST", hostname).replace("_REALM", defaultRealm);
 
-        commandReport = processIdentity(record, evaluatedPrincipal, operationHandler, kerberosConfiguration, requestSharedDataContext);
+  protected Set<String> getHostFilter() {
+    String serializedValue = getCommandParameterValue(HOST_FILTER);
+
+    if (serializedValue != null) {
+      Type type = new TypeToken<Set<String>>() {
+      }.getType();
+      return StageUtils.getGson().fromJson(serializedValue, type);
+    } else {
+      return null;
+    }
+  }
+
+  protected boolean hasHostFilters() {
+    Set<String> hostFilers = getHostFilter();
+    return hostFilers != null && hostFilers.size() > 0;
+  }
+
+
+  protected Map<String, Collection<String>> getServiceComponentFilter() {
+    String serializedValue = getCommandParameterValue(SERVICE_COMPONENT_FILTER);
+
+    if (serializedValue != null) {
+      Type type = new TypeToken<Map<String, ? extends Collection<String>>>() {
+      }.getType();
+      return StageUtils.getGson().fromJson(serializedValue, type);
+    } else {
+      return null;
+    }
+  }
+
+  protected Collection<String> getIdentityFilter() {
+    String serializedValue = getCommandParameterValue(IDENTITY_FILTER);
+
+    if (serializedValue != null) {
+      Type type = new TypeToken<Collection<String>>() {
+      }.getType();
+      return StageUtils.getGson().fromJson(serializedValue, type);
+    } else {
+      return null;
+    }
+  }
+
+  protected Long ambariServerHostID() {
+    String ambariServerHostName = StageUtils.getHostName();
+    HostEntity ambariServerHostEntity = hostDAO.findByName(ambariServerHostName);
+    return (ambariServerHostEntity == null)
+        ? null
+        : ambariServerHostEntity.getHostId();
+  }
+
+
+  /**
+   * Retrieve the current set of properties for the requested config type for the relevant cluster.
+   *
+   * @return a Map of property names to property values for the requested config type; or null if no data is found
+   * @throws AmbariException if an error occurs retrieving the relevant cluster details
+   */
+  protected Map<String, String> getConfigurationProperties(String configType) throws AmbariException {
+    if (StringUtils.isNotEmpty(configType)) {
+      Cluster cluster = getCluster();
+      Config config = (cluster == null) ? null : cluster.getDesiredConfigByType(configType);
+      Map<String, String> properties = (config == null) ? null : config.getProperties();
+
+      if (properties == null) {
+        LOG.warn("The '{}' configuration data is not available:" +
+                "\n\tcluster: {}" +
+                "\n\tconfig: {}" +
+                "\n\tproperties: null",
+            configType,
+            (cluster == null) ? "null" : "not null",
+            (config == null) ? "null" : "not null");
+      }
+
+      return properties;
+    } else {
+      return null;
+    }
+  }
+
+  public static class KerberosCommandParameters {
+    private Map<String, String> params;
+
+    public KerberosCommandParameters(ExecutionCommand ec) {
+      params = ec.getCommandParams();
+    }
+
+    public KerberosCommandParameters(AbstractServerAction serverAction) {
+      this(serverAction.getExecutionCommand());
+    }
+
+    public Set<String> getHostFilter() {
+      String serializedValue = getCommandParameterValue(HOST_FILTER);
+
+      if (serializedValue != null) {
+        Type type = new TypeToken<Set<String>>() {
+        }.getType();
+        return StageUtils.getGson().fromJson(serializedValue, type);
+      } else {
+        return null;
       }
     }
 
-    return commandReport;
+    public boolean hasHostFilters() {
+      Set<String> hostFilers = getHostFilter();
+      return hostFilers != null && hostFilers.size() > 0;
+    }
+
+    public Map<String, ? extends Collection<String>> getServiceComponentFilter() {
+      String serializedValue = getCommandParameterValue(SERVICE_COMPONENT_FILTER);
+
+      if (serializedValue != null) {
+        Type type = new TypeToken<Map<String, ? extends Collection<String>>>() {
+        }.getType();
+        return StageUtils.getGson().fromJson(serializedValue, type);
+      } else {
+        return null;
+      }
+    }
+
+    public Collection<String> getIdentityFilter() {
+      String serializedValue = getCommandParameterValue(IDENTITY_FILTER);
+
+      if (serializedValue != null) {
+        Type type = new TypeToken<Collection<String>>() {
+        }.getType();
+        return StageUtils.getGson().fromJson(serializedValue, type);
+      } else {
+        return null;
+      }
+    }
+
+    public String getCommandParameterValue(String propertyName) {
+      Map<String, String> commandParameters = params;
+      return (commandParameters == null) ? null : commandParameters.get(propertyName);
+    }
+  }
+
+  /**
+   * A Kerberos operation type
+   * <ul>
+   * <li>RECREATE_ALL - regenerate keytabs for all principals</li>
+   * <li>CREATE_MISSING - generate keytabs for only those that are missing</li>
+   * <li>DEFAULT - generate needed keytabs for new components</li>
+   * </ul>
+   */
+  public enum OperationType {
+    /**
+     * Regenerate keytabs for all principals
+     */
+    RECREATE_ALL,
+
+    /**
+     * Generate keytabs for only those that are missing
+     */
+    CREATE_MISSING,
+
+    /**
+     * Generate needed keytabs for new components
+     */
+    DEFAULT
   }
 }
