@@ -425,7 +425,7 @@ public class KerberosKeytabDescriptor extends AbstractKerberosDescriptor {
    */
   @Override
   public Map<String, Object> toMap() {
-    Map<String, Object> map = new TreeMap<String, Object>();
+    Map<String, Object> map = new TreeMap<>();
 
     String data;
 
@@ -433,7 +433,7 @@ public class KerberosKeytabDescriptor extends AbstractKerberosDescriptor {
     map.put(KEY_FILE, data);
 
     // Build file owner map
-    Map<String, String> owner = new TreeMap<String, String>();
+    Map<String, String> owner = new TreeMap<>();
 
     data = getOwnerName();
     if (data != null) {
@@ -451,7 +451,7 @@ public class KerberosKeytabDescriptor extends AbstractKerberosDescriptor {
     // Build file owner map (end)
 
     // Build file owner map
-    Map<String, String> group = new TreeMap<String, String>();
+    Map<String, String> group = new TreeMap<>();
 
     data = getGroupName();
     if (data != null) {
@@ -463,7 +463,7 @@ public class KerberosKeytabDescriptor extends AbstractKerberosDescriptor {
       group.put(KEY_ACL_ACCESS, data);
     }
 
-    if (!owner.isEmpty()) {
+    if (!group.isEmpty()) {
       map.put(KEY_GROUP, group);
     }
     // Build file owner map (end)
