@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -39,6 +39,7 @@ import org.apache.ambari.server.controller.jmx.JMXMetricHolder;
 import org.apache.ambari.server.controller.utilities.ScalingThreadPoolExecutor;
 import org.apache.ambari.server.controller.utilities.StreamProvider;
 import org.apache.commons.io.IOUtils;
+import org.codehaus.jackson.JsonParser;
 import org.codehaus.jackson.map.DeserializationConfig;
 import org.codehaus.jackson.map.ObjectMapper;
 import org.codehaus.jackson.map.ObjectReader;
@@ -59,7 +60,7 @@ import com.google.inject.Inject;
  * The {@link MetricsRetrievalService} is used as a headless, autonomous service
  * which encapsulates:
  * <ul>
- * <li>An {@link ExecutorService} for fullfilling remote metric URL requests
+ * <li>An {@link ExecutorService} for fulfilling remote metric URL requests
  * <li>A cache for JMX metrics
  * <li>A cache for REST metrics
  * </ul>
@@ -101,7 +102,7 @@ public class MetricsRetrievalService extends AbstractService {
   /**
    * Logger.
    */
-  protected final static Logger LOG = LoggerFactory.getLogger(MetricsRetrievalService.class);
+  private static final Logger LOG = LoggerFactory.getLogger(MetricsRetrievalService.class);
 
   /**
    * The timeout for exceptions which are caught and then cached to prevent log
@@ -182,6 +183,7 @@ public class MetricsRetrievalService extends AbstractService {
   public MetricsRetrievalService() {
     ObjectMapper jmxObjectMapper = new ObjectMapper();
     jmxObjectMapper.configure(DeserializationConfig.Feature.USE_ANNOTATIONS, false);
+    jmxObjectMapper.configure(JsonParser.Feature.ALLOW_NON_NUMERIC_NUMBERS, true);
     m_jmxObjectReader = jmxObjectMapper.reader(JMXMetricHolder.class);
   }
 
@@ -232,6 +234,7 @@ public class MetricsRetrievalService extends AbstractService {
       LOG.info("Metrics Retrieval Service request TTL cache is enabled and set to {} seconds",
           ttlSeconds);
     }
+    notifyStarted();
   }
 
   /**
@@ -257,6 +260,7 @@ public class MetricsRetrievalService extends AbstractService {
 
     m_queuedUrls.clear();
     m_threadPoolExecutor.shutdownNow();
+    notifyStopped();
   }
 
   /**
@@ -270,7 +274,7 @@ public class MetricsRetrievalService extends AbstractService {
    * {@link #getCachedRESTMetric(String)}, depending on the type of metric
    * requested.
    * <p/>
-   * Callers need not worry about invoking this mulitple times for the same URL
+   * Callers need not worry about invoking this multiple times for the same URL
    * endpoint. A single endpoint will only be enqueued once regardless of how
    * many times this method is called until it has been fully retrieved and
    * parsed. If the last endpoint request was too recent, then this method will
@@ -281,7 +285,7 @@ public class MetricsRetrievalService extends AbstractService {
    * @param streamProvider
    *          the {@link StreamProvider} to use to read from the remote
    *          endpoint.
-   * @param jmxUrl
+   * @param url
    *          the URL to read from
    *
    * @see #getCachedJMXMetric(String)
@@ -349,7 +353,7 @@ public class MetricsRetrievalService extends AbstractService {
    * Gets a cached REST metric in the form of a {@link Map}. If there is no
    * metric data cached for the given URL, then {@code null} is returned.
    * <p/>
-   * The onky way this cache is populated is by requesting the data to be loaded
+   * The only way this cache is populated is by requesting the data to be loaded
    * asynchronously via
    * {@link #submitRequest(MetricSourceType, StreamProvider, String)} with the
    * {@link MetricSourceType#REST} type.
@@ -363,7 +367,7 @@ public class MetricsRetrievalService extends AbstractService {
   }
 
   /**
-   * Encapsulates the common logic for all metric {@link Runnable} instnaces.
+   * Encapsulates the common logic for all metric {@link Runnable} instances.
    */
   private static abstract class MetricRunnable implements Runnable {
 
@@ -399,7 +403,7 @@ public class MetricsRetrievalService extends AbstractService {
      *          the URLs which are currently waiting to be processed. This
      *          method will remove the specified URL from this {@link Set} when
      *          it completes (successful or not).
-     * @param m_ttlUrlCache
+     * @param ttlUrlCache
      *          an evicting cache which is used to determine if a request for a
      *          metric is too soon after the last request, or {@code null} if
      *          requests can be made sequentially without any separation.
@@ -501,7 +505,7 @@ public class MetricsRetrievalService extends AbstractService {
      *
      * @param throwable
      * @param url
-     * @return the key, such as {@value IOException-http://www.server.com/jmx}.
+     * @return the key, such as <code>IOException-http://www.server.com/jmx</code>.
      */
     private String buildCacheKey(Throwable throwable, String url) {
       if (null == throwable || null == url) {
