@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,11 +17,12 @@
  */
 package org.apache.ambari.server.view.configuration;
 
+import java.util.Collections;
+import java.util.List;
+
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
-import java.util.Collections;
-import java.util.List;
 
 /**
  * View persistence configuration.
@@ -40,6 +41,6 @@ public class PersistenceConfig {
    * @return the entity configurations
    */
   public List<EntityConfig> getEntities() {
-    return entities == null ? Collections.<EntityConfig>emptyList() : entities;
+    return entities == null ? Collections.emptyList() : entities;
   }
 }
