@@ -35,8 +35,6 @@ import ambari_simplejson as json
 import ambari_commons.network as network
 import os
 
-GRAFANA_CONNECT_TRIES = 15
-GRAFANA_CONNECT_TIMEOUT = 20
 GRAFANA_SEARCH_BUILTIN_DASHBOARDS = "/api/search?tag=builtin"
 GRAFANA_DATASOURCE_URL = "/api/datasources"
 GRAFANA_USER_URL = "/api/user"
@@ -46,14 +44,15 @@ METRICS_GRAFANA_DATASOURCE_NAME = "AMBARI_METRICS"
 Server = namedtuple('Server', [ 'protocol', 'host', 'port', 'user', 'password' ])
 
 def perform_grafana_get_call(url, server):
+  import params
+
   grafana_https_enabled = server.protocol.lower() == 'https'
   response = None
   ca_certs = None
   if grafana_https_enabled:
-    import params
     ca_certs = params.ams_grafana_ca_cert
 
-  for i in xrange(0, GRAFANA_CONNECT_TRIES):
+  for i in xrange(0, params.grafana_connect_attempts):
     try:
       conn = network.get_http_connection(
         server.host,
@@ -73,10 +72,10 @@ def perform_grafana_get_call(url, server):
       Logger.info("Http response: %s %s" % (response.status, response.reason))
       break
     except (httplib.HTTPException, socket.error) as ex:
-      if i < GRAFANA_CONNECT_TRIES - 1:
-        time.sleep(GRAFANA_CONNECT_TIMEOUT)
+      if i < params.grafana_connect_attempts - 1:
         Logger.info("Connection to Grafana failed. Next retry in %s seconds."
-                    % (GRAFANA_CONNECT_TIMEOUT))
+                    % (params.grafana_connect_retry_delay))
+        time.sleep(params.grafana_connect_retry_delay)
         continue
       else:
         raise Fail("Ambari Metrics Grafana update failed due to: %s" % str(ex))
@@ -85,6 +84,8 @@ def perform_grafana_get_call(url, server):
   return response
 
 def perform_grafana_put_call(url, id, payload, server):
+  import params
+
   response = None
   data = None
   userAndPass = b64encode('{0}:{1}'.format(server.user, server.password))
@@ -94,10 +95,9 @@ def perform_grafana_put_call(url, id, payload, server):
 
   ca_certs = None
   if grafana_https_enabled:
-    import params
     ca_certs = params.ams_grafana_ca_cert
 
-  for i in xrange(0, GRAFANA_CONNECT_TRIES):
+  for i in xrange(0, params.grafana_connect_attempts):
     try:
       conn = network.get_http_connection(
         server.host,
@@ -113,10 +113,10 @@ def perform_grafana_put_call(url, id, payload, server):
       conn.close()
       break
     except (httplib.HTTPException, socket.error) as ex:
-      if i < GRAFANA_CONNECT_TRIES - 1:
-        time.sleep(GRAFANA_CONNECT_TIMEOUT)
+      if i < params.grafana_connect_attempts - 1:
         Logger.info("Connection to Grafana failed. Next retry in %s seconds."
-                    % (GRAFANA_CONNECT_TIMEOUT))
+                    % (params.grafana_connect_retry_delay))
+        time.sleep(params.grafana_connect_retry_delay)
         continue
       else:
         raise Fail("Ambari Metrics Grafana update failed due to: %s" % str(ex))
@@ -125,6 +125,8 @@ def perform_grafana_put_call(url, id, payload, server):
   return (response, data)
 
 def perform_grafana_post_call(url, payload, server):
+  import params
+
   response = None
   data = None
   userAndPass = b64encode('{0}:{1}'.format(server.user, server.password))
@@ -135,10 +137,9 @@ def perform_grafana_post_call(url, payload, server):
 
   ca_certs = None
   if grafana_https_enabled:
-    import params
     ca_certs = params.ams_grafana_ca_cert
 
-  for i in xrange(0, GRAFANA_CONNECT_TRIES):
+  for i in xrange(0, params.grafana_connect_attempts):
     try:
       Logger.info("Connecting (POST) to %s:%s%s" % (server.host, server.port, url))
       conn = network.get_http_connection(
@@ -147,26 +148,26 @@ def perform_grafana_post_call(url, payload, server):
         grafana_https_enabled, ca_certs,
         ssl_version=Script.get_force_https_protocol_value()
       )
-      
+
       conn.request("POST", url, payload, headers)
 
       response = conn.getresponse()
       Logger.info("Http response: %s %s" % (response.status, response.reason))
       if response.status == 401: #Intermittent error thrown from Grafana
-        if i < GRAFANA_CONNECT_TRIES - 1:
-          time.sleep(GRAFANA_CONNECT_TIMEOUT)
+        if i < params.grafana_connect_attempts - 1:
           Logger.info("Connection to Grafana failed. Next retry in %s seconds."
-                  % (GRAFANA_CONNECT_TIMEOUT))
+                  % (params.grafana_connect_retry_delay))
+          time.sleep(params.grafana_connect_retry_delay)
           continue
       data = response.read()
       Logger.info("Http data: %s" % data)
       conn.close()
       break
     except (httplib.HTTPException, socket.error) as ex:
-      if i < GRAFANA_CONNECT_TRIES - 1:
-        time.sleep(GRAFANA_CONNECT_TIMEOUT)
+      if i < params.grafana_connect_attempts - 1:
         Logger.info("Connection to Grafana failed. Next retry in %s seconds."
-                    % (GRAFANA_CONNECT_TIMEOUT))
+                    % (params.grafana_connect_retry_delay))
+        time.sleep(params.grafana_connect_retry_delay)
         continue
       else:
         raise Fail("Ambari Metrics Grafana update failed due to: %s" % str(ex))
@@ -175,15 +176,16 @@ def perform_grafana_post_call(url, payload, server):
   return (response, data)
 
 def perform_grafana_delete_call(url, server):
+  import params
+
   grafana_https_enabled = server.protocol.lower() == 'https'
   response = None
 
   ca_certs = None
   if grafana_https_enabled:
-    import params
     ca_certs = params.ams_grafana_ca_cert
 
-  for i in xrange(0, GRAFANA_CONNECT_TRIES):
+  for i in xrange(0, params.grafana_connect_attempts):
     try:
       conn = network.get_http_connection(
         server.host,
@@ -202,10 +204,10 @@ def perform_grafana_delete_call(url, server):
       Logger.info("Http response: %s %s" % (response.status, response.reason))
       break
     except (httplib.HTTPException, socket.error) as ex:
-      if i < GRAFANA_CONNECT_TRIES - 1:
-        time.sleep(GRAFANA_CONNECT_TIMEOUT)
+      if i < params.grafana_connect_attempts - 1:
         Logger.info("Connection to Grafana failed. Next retry in %s seconds."
-                    % (GRAFANA_CONNECT_TIMEOUT))
+                    % (params.grafana_connect_retry_delay))
+        time.sleep(params.grafana_connect_retry_delay)
         continue
       else:
         raise Fail("Ambari Metrics Grafana update failed due to: %s" % str(ex))
@@ -244,25 +246,25 @@ def create_grafana_admin_pwd():
   import params
 
   serverCall1 = Server(protocol = params.ams_grafana_protocol.strip(),
-                   host = params.ams_grafana_host.strip(),
-                   port = params.ams_grafana_port,
-                   user = params.ams_grafana_admin_user,
-                   password = params.ams_grafana_admin_pwd)
+                       host = params.ams_grafana_host.strip(),
+                       port = params.ams_grafana_port,
+                       user = params.ams_grafana_admin_user,
+                       password = params.ams_grafana_admin_pwd)
 
   response = perform_grafana_get_call(GRAFANA_USER_URL, serverCall1)
   if response and response.status != 200:
 
     serverCall2 = Server(protocol = params.ams_grafana_protocol.strip(),
-                     host = params.ams_grafana_host.strip(),
-                     port = params.ams_grafana_port,
-                     user = params.ams_grafana_admin_user,
-                     password = 'admin')
+                         host = params.ams_grafana_host.strip(),
+                         port = params.ams_grafana_port,
+                         user = params.ams_grafana_admin_user,
+                         password = 'admin')
 
     Logger.debug("Setting grafana admin password")
     pwd_data = {  "oldPassword": "admin",
-                     "newPassword": params.ams_grafana_admin_pwd,
-                     "confirmNew": params.ams_grafana_admin_pwd
-                     }
+                  "newPassword": params.ams_grafana_admin_pwd,
+                  "confirmNew": params.ams_grafana_admin_pwd
+                  }
     password_json = json.dumps(pwd_data)
 
     (response, data) = perform_grafana_put_call(GRAFANA_USER_URL, 'password', password_json, serverCall2)
@@ -307,7 +309,7 @@ def create_ams_datasource():
 
   if new_datasource_host == "":
     Logger.warning("All metric collectors are unavailable. Will use random collector as datasource host.")
-    new_datasource_host = params.random_metric_collector_host
+    new_datasource_host = params.metric_collector_host
 
   Logger.info("New datasource host will be %s" % new_datasource_host)
 
@@ -328,13 +330,26 @@ def create_ams_datasource():
         Logger.info("Ambari Metrics Grafana datasource already present. Checking Metrics Collector URL")
         datasource_url = datasources_json[i]["url"]
 
+        update_datasource = False
         if is_unchanged_datasource_url(datasource_url, new_datasource_host):
           Logger.info("Metrics Collector URL validation succeeded.")
-          return
-        else: # Metrics datasource present, but collector host is wrong.
+        else:
+          Logger.info("Metrics Collector URL validation failed.")
+          update_datasource = True
+
+        datasource_type = datasources_json[i]["type"]
+        new_datasource_def = json.loads(ams_datasource_json)
+        new_datasource_type = new_datasource_def["type"]
+
+        if datasource_type == new_datasource_type:
+          Logger.info("Grafana datasource type validation succeeded.")
+        else:
+          Logger.info("Grafana datasource type validation failed. Old type = %s, New type = %s" % (datasource_type, new_datasource_type))
+          update_datasource = True
+
+        if update_datasource: # Metrics datasource present, but collector host is wrong or the datasource type is outdated.
           datasource_id = datasources_json[i]["id"]
-          Logger.info("Metrics Collector URL validation failed. Updating "
-                      "datasource, id = %s" % datasource_id)
+          Logger.info("Updating datasource, id = %s" % datasource_id)
 
           (response, data) = perform_grafana_put_call(GRAFANA_DATASOURCE_URL, datasource_id,
                                                       ams_datasource_json, server)
@@ -472,3 +487,4 @@ def create_ams_dashboards():
     pass
 
 
+
