@@ -21,11 +21,11 @@ limitations under the License.
 
 import os
 from ambari_commons.constants import AMBARI_SUDO_BINARY
-from logsearch_config_aggregator import get_logfeeder_metadata, get_logsearch_metadata, get_logsearch_meta_configs
 from resource_management.libraries.functions.default import default
 from resource_management.libraries.functions.format import format
 from resource_management.libraries.functions.is_empty import is_empty
 from resource_management.libraries.script.script import Script
+
 import status_params
 
 
@@ -57,9 +57,9 @@ credential_store_enabled = False
 if 'credentialStoreEnabled' in config:
   credential_store_enabled = config['credentialStoreEnabled']
 
-logsearch_server_conf = "/etc/ambari-logsearch-portal/conf"
+logsearch_server_conf = "/usr/lib/ambari-logsearch-portal/conf"
 logsearch_server_keys_folder = logsearch_server_conf + "/keys"
-logsearch_logfeeder_conf = "/etc/ambari-logsearch-logfeeder/conf"
+logsearch_logfeeder_conf = "/usr/lib/ambari-logsearch-logfeeder/conf"
 logsearch_logfeeder_keys_folder = logsearch_logfeeder_conf + "/keys"
 
 logsearch_config_set_dir = format("{logsearch_server_conf}/solr_configsets")
@@ -75,13 +75,12 @@ logfeeder_pid_file = status_params.logfeeder_pid_file
 user_group = config['configurations']['cluster-env']['user_group']
 
 # shared configs
-java64_home = config['hostLevelParams']['java_home']
+java_home = config['ambariLevelParams']['java_home']
+ambari_java_home = default("/commandParams/ambari_java_home", None)
+java64_home = ambari_java_home if ambari_java_home is not None else java_home
 cluster_name = str(config['clusterName'])
 
 configurations = config['configurations'] # need reference inside logfeeder jinja templates
-logserch_meta_configs = get_logsearch_meta_configs(configurations)
-logsearch_metadata = get_logsearch_metadata(logserch_meta_configs)
-logfeeder_metadata = get_logfeeder_metadata(logserch_meta_configs)
 
 # for now just pick first collector
 if 'metrics_collector_hosts' in config['clusterHostInfo']:
@@ -116,7 +115,8 @@ infra_solr_role_logfeeder = default('configurations/infra-solr-security-json/inf
 infra_solr_role_dev = default('configurations/infra-solr-security-json/infra_solr_role_dev', 'dev')
 infra_solr_role_ranger_admin = default('configurations/infra-solr-security-json/infra_solr_role_ranger_admin', 'ranger_user')
 
-_hostname_lowercase = config['hostname'].lower()
+_hostname_lowercase = config['agentLevelParams']['hostname'].lower()
+logsearch_jaas_file = None
 if security_enabled:
   kinit_path_local = status_params.kinit_path_local
   logsearch_jaas_file = logsearch_server_conf + '/logsearch_jaas.conf'
@@ -133,6 +133,21 @@ if security_enabled:
     logfeeder_kerberos_keytab = config['configurations']['logfeeder-env']['logfeeder_kerberos_keytab']
     logfeeder_kerberos_principal = config['configurations']['logfeeder-env']['logfeeder_kerberos_principal'].replace('_HOST',_hostname_lowercase)
 
+  zookeeper_principal_name = default("/configurations/zookeeper-env/zookeeper_principal_name", "zookeeper/_HOST@EXAMPLE.COM")
+  external_zk_principal_enabled = default("/configurations/logsearch-common-env/logsearch_zookeeper_external_principal", False)
+  external_zk_principal_name = default("/configurations/logsearch-common-env/logsearch_zookeeper_external_principal", "zookeeper/_HOST@EXAMPLE.COM")
+  zk_principal_name = external_zk_principal_name if external_zk_principal_enabled else zookeeper_principal_name
+  zk_principal_user = zk_principal_name.split('/')[0]
+  zk_security_opts = format('-Dzookeeper.sasl.client=true -Dzookeeper.sasl.client.username={zk_principal_user} -Dzookeeper.sasl.clientconfig=Client')
+
+  logsearch_solr_service_users = []
+  logsearch_kerberos_service_user = get_name_from_principal(logsearch_kerberos_principal)
+  logsearch_solr_service_users.append(logsearch_kerberos_service_user)
+  logsearch_kerberos_service_users_str = str(default('/configurations/logsearch-env/logsearch_kerberos_service_users', ''))
+  if logsearch_kerberos_service_users_str and logsearch_kerberos_service_users_str.strip():
+    logsearch_kerberos_service_users = logsearch_kerberos_service_users_str.split(',')
+    logsearch_solr_service_users.extend(logsearch_kerberos_service_users)
+
 logsearch_spnego_host = config['configurations']['logsearch-properties']['logsearch.spnego.kerberos.host'].replace('_HOST', _hostname_lowercase)
 
 #####################################
@@ -158,8 +173,8 @@ else:
 
   logsearch_solr_zk_quorum = ""
   zookeeper_port = default('/configurations/zoo.cfg/clientPort', None)
-  if 'zookeeper_hosts' in config['clusterHostInfo']:
-    for host in config['clusterHostInfo']['zookeeper_hosts']:
+  if 'zookeeper_server_hosts' in config['clusterHostInfo']:
+    for host in config['clusterHostInfo']['zookeeper_server_hosts']:
       if logsearch_solr_zk_quorum:
         logsearch_solr_zk_quorum += ','
       logsearch_solr_zk_quorum += host + ":" + str(zookeeper_port)
@@ -172,9 +187,7 @@ zookeeper_quorum = logsearch_solr_zk_quorum
 # logsearch-env configs
 logsearch_user = config['configurations']['logsearch-env']['logsearch_user']
 logsearch_log_dir = config['configurations']['logsearch-env']['logsearch_log_dir']
-logsearch_log = logsearch_log_dir + '/logsearch.out'
-logsearch_ui_protocol = config['configurations']['logsearch-env']["logsearch_ui_protocol"]
-logsearch_ui_port = config['configurations']['logsearch-env']["logsearch_ui_port"]
+logsearch_log = 'logsearch.out'
 logsearch_debug_enabled = str(config['configurations']['logsearch-env']["logsearch_debug_enabled"]).lower()
 logsearch_debug_port = config['configurations']['logsearch-env']["logsearch_debug_port"]
 logsearch_app_max_memory = config['configurations']['logsearch-env']['logsearch_app_max_memory']
@@ -206,9 +219,8 @@ logsearch_audit_logs_solrconfig_content = config['configurations']['logsearch-au
 logsearch_app_log4j_content = config['configurations']['logsearch-log4j']['content']
 
 # Log dirs
-ambari_server_log_dir = '/var/log/ambari-server'
-ambari_agent_log_dir = '/var/log/ambari-agent'
-nifi_log_dir = default('/configurations/nifi-env/nifi_node_log_dir', '/var/log/nifi')
+ambari_server_log_dir = default('/configurations/logfeeder-env/ambari_server_log_dir', "/var/log/ambari-server")
+ambari_agent_log_dir = default('/configurations/logfeeder-env/ambari_agent_log_dir', "/var/log/ambari-agent")
 
 # System logs
 logfeeder_system_messages_content = config['configurations']['logfeeder-system_log-env']['logfeeder_system_messages_content']
@@ -223,10 +235,10 @@ logsearch_admin_password = default('/configurations/logsearch-admin-json/logsear
 logsearch_admin_content = config['configurations']['logsearch-admin-json']['content']
 
 # for now just pick first collector
-if 'ambari_server_host' in config['clusterHostInfo']:
-  ambari_server_host = config['clusterHostInfo']['ambari_server_host'][0]
-  ambari_server_port = config['clusterHostInfo']['ambari_server_port'][0]
-  ambari_server_use_ssl = config['clusterHostInfo']['ambari_server_use_ssl'][0] == 'true'
+if 'ambari_server_host' in config['ambariLevelParams']:
+  ambari_server_host = config['ambariLevelParams']['ambari_server_host']
+  ambari_server_port = config['ambariLevelParams']['ambari_server_port']
+  ambari_server_use_ssl = config['ambariLevelParams']['ambari_server_use_ssl']
   
   ambari_server_protocol = 'https' if ambari_server_use_ssl else 'http'
 
@@ -236,6 +248,10 @@ else:
 
 # Logsearch propreties
 
+logsearch_protocol = config['configurations']['logsearch-properties']["logsearch.protocol"]
+logsearch_http_port = config['configurations']['logsearch-properties']["logsearch.http.port"]
+logsearch_https_port = config['configurations']['logsearch-properties']["logsearch.https.port"]
+
 logsearch_properties = {}
 
 # default values
@@ -245,7 +261,7 @@ logsearch_properties['logsearch.solr.audit.logs.zk_connect_string'] = logsearch_
 
 logsearch_properties['logsearch.solr.collection.history'] = 'history'
 logsearch_properties['logsearch.solr.history.config.name'] = 'history'
-logsearch_properties['logsearch.collection.history.replication.factor'] = '1'
+logsearch_properties['logsearch.collection.history.replication.factor'] = '2'
 
 logsearch_properties['logsearch.solr.jmx.port'] = infra_solr_jmx_port
 
@@ -254,19 +270,11 @@ logsearch_properties['logsearch.auth.file.enabled'] = 'true'
 logsearch_properties['logsearch.auth.ldap.enabled'] = 'false'
 logsearch_properties['logsearch.auth.simple.enabled'] = 'false'
 
-logsearch_properties['logsearch.protocol'] = logsearch_ui_protocol
-
-logsearch_acls = ''
-if 'infra-solr-env' in config['configurations'] and security_enabled and not logsearch_use_external_solr:
-  acl_infra_solr_principal = get_name_from_principal(config['configurations']['infra-solr-env']['infra_solr_kerberos_principal'])
-  acl_logsearch_principal = get_name_from_principal(config['configurations']['logsearch-env']['logsearch_kerberos_principal'])
-  logsearch_acls = format('world:anyone:r,sasl:{acl_infra_solr_principal}:cdrwa,sasl:{acl_logsearch_principal}:cdrwa')
-  logsearch_properties['logsearch.solr.zk.acls'] = logsearch_acls
-  logsearch_properties['logsearch.solr.audit.logs.zk.acls'] = logsearch_acls
-
 # load config values
 
-logsearch_properties = dict(logsearch_properties.items() + dict(config['configurations']['logsearch-properties']).items())
+logsearch_properties = dict(logsearch_properties.items() +\
+                       dict(config['configurations']['logsearch-common-properties']).items() +\
+                       dict(config['configurations']['logsearch-properties']).items())
 
 # load derivated values
 
@@ -279,6 +287,9 @@ logsearch_properties['logsearch.solr.metrics.collector.hosts'] = format(logsearc
 logsearch_properties['logsearch.auth.external_auth.host_url'] = format(logsearch_properties['logsearch.auth.external_auth.host_url'])
 logsearch_properties['logsearch.spnego.kerberos.host'] = logsearch_spnego_host
 
+if not('logsearch.config.zk_connect_string' in logsearch_properties):
+  logsearch_properties['logsearch.config.zk_connect_string'] = logsearch_solr_zk_quorum
+
 if logsearch_solr_kerberos_enabled:
   logsearch_properties['logsearch.solr.kerberos.enable'] = 'true'
   logsearch_properties['logsearch.solr.jaas.file'] = logsearch_jaas_file
@@ -294,7 +305,7 @@ logsearch_collection_audit_logs_numshards = logsearch_properties['logsearch.coll
 
 # check if logsearch uses ssl in any way
 
-logsearch_use_ssl = logsearch_solr_ssl_enabled or logsearch_ui_protocol == 'https' or ambari_server_use_ssl
+logsearch_use_ssl = logsearch_solr_ssl_enabled or logsearch_protocol == 'https' or ambari_server_use_ssl
 
 #####################################
 # Logfeeder configs
@@ -310,7 +321,7 @@ logfeeder_json_log_maxbackupindex = default('/configurations/logfeeder-log4j/log
 
 # logfeeder-env configs
 logfeeder_log_dir = config['configurations']['logfeeder-env']['logfeeder_log_dir']
-logfeeder_log = logfeeder_log_dir + '/logfeeder.out'
+logfeeder_log = 'logfeeder.out'
 logfeeder_max_mem = config['configurations']['logfeeder-env']['logfeeder_max_mem']
 solr_service_logs_enable = default('/configurations/logfeeder-env/logfeeder_solr_service_logs_enable', True)
 solr_audit_logs_enable = default('/configurations/logfeeder-env/logfeeder_solr_audit_logs_enable', True)
@@ -329,18 +340,18 @@ logfeeder_env_jceks_file = os.path.join(logsearch_logfeeder_conf, 'logfeeder.jce
 
 logfeeder_ambari_config_content = config['configurations']['logfeeder-ambari-config']['content']
 logfeeder_output_config_content = config['configurations']['logfeeder-output-config']['content']
+logfeeder_kafka_output_config_content = config['configurations']['logfeeder-kafka-output-config']['content']
 
-logfeeder_default_services = ['logsearch']
-logfeeder_default_config_file_names = ['global.config.json'] + ['input.config-%s.json' % (tag) for tag in logfeeder_default_services]
-logfeeder_custom_config_file_names = ['input.config-%s.json' % (tag.replace('-logsearch-conf', ''))
-                                      for tag, content in logfeeder_metadata.iteritems() if any(logfeeder_metadata)]
+logfeeder_kafka_output_enabled = False
+if 'logfeeder-kafka-output-config' in config['configurations']:
+  logfeeder_kafka_output_enabled = default('/configurations/logfeeder-kafka-output-config/logfeeder_kafka_output_enabled', False)
+  logfeeder_kafka_broker_list = default('/configurations/logfeeder-kafka-output-config/logfeeder_kafka_broker_list', 'localhost:6667')
+  logfeeder_kafka_topic = default('/configurations/logfeeder-kafka-output-config/logfeeder_kafka_topic', 'log-streaming')
 
-if logfeeder_system_log_enabled:
-  default_config_files = ','.join(['output.config.json','input.config-ambari.json'] + logfeeder_default_config_file_names + logfeeder_custom_config_file_names
-                                  + ['input.config-system_messages.json', 'input.config-secure_log.json'])
+if logfeeder_kafka_output_enabled:
+  default_config_files = ','.join(['output.config.json','global.config.json', 'kafka-output.json'])
 else:
-  default_config_files = ','.join(['output.config.json','input.config-ambari.json'] + logfeeder_default_config_file_names + logfeeder_custom_config_file_names)
-
+  default_config_files = ','.join(['output.config.json','global.config.json'])
 
 logfeeder_grok_patterns = config['configurations']['logfeeder-grok']['default_grok_patterns']
 if config['configurations']['logfeeder-grok']['custom_grok_patterns'].strip():
@@ -363,18 +374,25 @@ logfeeder_properties['logfeeder.solr.core.config.name'] = 'history'
 
 # load config values
 
-logfeeder_properties = dict(logfeeder_properties.items() + dict(config['configurations']['logfeeder-properties']).items())
+logfeeder_properties = dict(logfeeder_properties.items() +\
+                       dict(config['configurations']['logsearch-common-properties']).items() +\
+                       dict(config['configurations']['logfeeder-properties']).items())
 
 # load derivated values
 
-logfeeder_properties['logfeeder.metrics.collector.hosts'] = format(logfeeder_properties['logfeeder.metrics.collector.hosts'])
+logfeeder_properties['cluster.name'] = cluster_name
+logfeeder_properties['logfeeder.config.dir'] = logsearch_logfeeder_conf
 logfeeder_properties['logfeeder.config.files'] = format(logfeeder_properties['logfeeder.config.files'])
 logfeeder_properties['logfeeder.solr.zk_connect_string'] = logsearch_solr_zk_quorum + logsearch_solr_zk_znode
 
+logfeeder_properties['logfeeder.metrics.collector.hosts'] = format(logfeeder_properties['logfeeder.metrics.collector.hosts'])
 logfeeder_properties['logfeeder.metrics.collector.protocol'] = metrics_collector_protocol
 logfeeder_properties['logfeeder.metrics.collector.port'] = metrics_collector_port
 logfeeder_properties['logfeeder.metrics.collector.path'] = '/ws/v1/timeline/metrics'
 
+if not('logsearch.config.zk_connect_string' in logfeeder_properties):
+  logfeeder_properties['logsearch.config.zk_connect_string'] = logsearch_solr_zk_quorum
+
 if logsearch_solr_kerberos_enabled:
   if 'logfeeder.solr.kerberos.enable' not in logfeeder_properties:
     logfeeder_properties['logfeeder.solr.kerberos.enable'] = 'true'
@@ -387,12 +405,25 @@ logfeeder_checkpoint_folder = logfeeder_properties['logfeeder.checkpoint.folder'
 
 logfeeder_use_ssl = logsearch_solr_ssl_enabled or metrics_collector_protocol == 'https'
 
+logsearch_acls = ''
+if 'infra-solr-env' in config['configurations'] and security_enabled and not logsearch_use_external_solr:
+  acl_infra_solr_principal = get_name_from_principal(config['configurations']['infra-solr-env']['infra_solr_kerberos_principal'])
+  acl_logsearch_principal = get_name_from_principal(config['configurations']['logsearch-env']['logsearch_kerberos_principal'])
+  logsearch_acls = format('world:anyone:r,sasl:{acl_infra_solr_principal}:cdrwa,sasl:{acl_logsearch_principal}:cdrwa')
+  logsearch_properties['logsearch.solr.zk.acls'] = logsearch_acls
+  logsearch_properties['logsearch.solr.audit.logs.zk.acls'] = logsearch_acls
+  if not('logsearch.config.zk_acls' in logsearch_properties):
+    logsearch_properties['logsearch.config.zk_acls'] = logsearch_acls
+  if not('logsearch.config.zk_acls' in logfeeder_properties):
+    logfeeder_properties['logsearch.config.zk_acls'] = logsearch_acls
+
 #####################################
 # Smoke command
 #####################################
 
 logsearch_server_hosts = default('/clusterHostInfo/logsearch_server_hosts', None)
 logsearch_server_host = ""
+logsearch_ui_port =  logsearch_https_port if logsearch_protocol == 'https' else logsearch_http_port
 if logsearch_server_hosts is not None and len(logsearch_server_hosts) > 0:
   logsearch_server_host = logsearch_server_hosts[0]
-smoke_logsearch_cmd = format('curl -k -s -o /dev/null -w "%{{http_code}}" {logsearch_ui_protocol}://{logsearch_server_host}:{logsearch_ui_port}/login.html | grep 200')
+smoke_logsearch_cmd = format('curl -k -s -o /dev/null -w "%{{http_code}}" {logsearch_protocol}://{logsearch_server_host}:{logsearch_ui_port}/api/v1/info | grep 200')
