@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,20 +18,26 @@
 
 package org.apache.ambari.server.state;
 
-import com.google.common.collect.Lists;
-import org.apache.ambari.server.state.stack.ServiceMetainfoXml;
-import org.junit.Test;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 
-import javax.xml.bind.JAXBContext;
-import javax.xml.bind.JAXBException;
-import javax.xml.bind.Unmarshaller;
 import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import static org.junit.Assert.*;
+import javax.xml.bind.JAXBContext;
+import javax.xml.bind.JAXBException;
+import javax.xml.bind.Unmarshaller;
+
+import org.apache.ambari.server.state.stack.ServiceMetainfoXml;
+import org.junit.Test;
+
+import com.google.common.collect.Lists;
 
 /**
  * ServiceInfo tests.
@@ -73,35 +79,35 @@ public class ServiceInfoTest {
         "    </service>\n" +
         "  </services>\n" +
         "</metainfo>\n";
-    
+
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
 
     assertTrue(serviceInfoMap.get("RESTART").isRestartRequiredAfterRackChange());
     assertFalse(serviceInfoMap.get("NO_RESTART").isRestartRequiredAfterRackChange());
     assertNull(serviceInfoMap.get("DEFAULT_RESTART").isRestartRequiredAfterRackChange());
-    assertEquals(serviceInfoMap.get("HCFS_SERVICE").getServiceType(),"HCFS");
+    assertEquals(serviceInfoMap.get("HCFS_SERVICE").getServiceType(), "HCFS");
   }
 
   @Test
   public void testCustomMetricsWidgetsFiles() throws Exception {
 
     String serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>CUSTOM</name>\n" +
-            "      <displayName>CUSTOM</displayName>\n" +
-            "      <metricsFileName>CUSTOM_metrics.json</metricsFileName>\n" +
-            "      <widgetsFileName>CUSTOM_widgets.json</widgetsFileName>\n" +
-            "    </service>\n" +
-            "    <service>\n" +
-            "      <name>DEFAULT</name>\n" +
-            "      <displayName>DEFAULT</displayName>\n" +
-            "      <comment>Apache Hadoop Distributed File System</comment>\n" +
-            "      <version>2.1.0.2.0</version>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>CUSTOM</name>\n" +
+        "      <displayName>CUSTOM</displayName>\n" +
+        "      <metricsFileName>CUSTOM_metrics.json</metricsFileName>\n" +
+        "      <widgetsFileName>CUSTOM_widgets.json</widgetsFileName>\n" +
+        "    </service>\n" +
+        "    <service>\n" +
+        "      <name>DEFAULT</name>\n" +
+        "      <displayName>DEFAULT</displayName>\n" +
+        "      <comment>Apache Hadoop Distributed File System</comment>\n" +
+        "      <version>2.1.0.2.0</version>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
 
@@ -143,26 +149,27 @@ public class ServiceInfoTest {
 
   /**
    * Tests the presence and absence of the credential-store block.
+   *
    * @throws Exception
-     */
+   */
   @Test
   public void testCredentialStoreFields() throws Exception {
     /*
      * <credential-store> supported and enabled.
      */
     String serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>true</supported>\n" +
-            "          <enabled>true</enabled>\n" +
-            "          <required>true</required>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>true</supported>\n" +
+        "          <enabled>true</enabled>\n" +
+        "          <required>true</required>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
     ServiceInfo service = serviceInfoMap.get("RANGER");
     assertTrue(service.isCredentialStoreSupported());
@@ -173,18 +180,18 @@ public class ServiceInfoTest {
      * <credential-store> supported but not enabled.
      */
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>HIVE</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>true</supported>\n" +
-            "          <enabled>false</enabled>\n" +
-            "          <required>false</required>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>HIVE</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>true</supported>\n" +
+        "          <enabled>false</enabled>\n" +
+        "          <required>false</required>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     service = serviceInfoMap.get("HIVE");
     assertTrue(service.isCredentialStoreSupported());
@@ -195,13 +202,13 @@ public class ServiceInfoTest {
      * <credential-store> is missing
      */
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>AMBARI_METRICS</name>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>AMBARI_METRICS</name>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     service = serviceInfoMap.get("AMBARI_METRICS");
     assertFalse(service.isCredentialStoreSupported());
@@ -212,16 +219,16 @@ public class ServiceInfoTest {
      * scenario. So both values should be false.
      */
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>HBASE</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>true</supported>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>HBASE</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>true</supported>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     service = serviceInfoMap.get("HBASE");
     assertTrue(service.isCredentialStoreSupported());
@@ -229,21 +236,20 @@ public class ServiceInfoTest {
   }
 
   @Test
-  public void testCredentialStoreInfoValidity() throws Exception
-  {
+  public void testCredentialStoreInfoValidity() throws Exception {
     // Valid: Supported->True, Enabled->False
     String serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>true</supported>\n" +
-            "          <enabled>false</enabled>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>true</supported>\n" +
+        "          <enabled>false</enabled>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
     ServiceInfo serviceInfo = serviceInfoMap.get("RANGER");
@@ -251,17 +257,17 @@ public class ServiceInfoTest {
 
     // Valid: Supported->True, Enabled->True
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>true</supported>\n" +
-            "          <enabled>true</enabled>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>true</supported>\n" +
+        "          <enabled>true</enabled>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -269,17 +275,17 @@ public class ServiceInfoTest {
 
     // Valid: Supported->False, Enabled->False
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>false</supported>\n" +
-            "          <enabled>false</enabled>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>false</supported>\n" +
+        "          <enabled>false</enabled>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -287,13 +293,13 @@ public class ServiceInfoTest {
 
     // Valid: credential-store not specified
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -302,17 +308,17 @@ public class ServiceInfoTest {
     // Specified but invalid
     // Invalid: Supported->False, Enabled->True
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>false</supported>\n" +
-            "          <enabled>true</enabled>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>false</supported>\n" +
+        "          <enabled>true</enabled>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -320,15 +326,15 @@ public class ServiceInfoTest {
 
     // Invalid: Supported->Unspecified, Enabled->Unspecified
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -336,16 +342,16 @@ public class ServiceInfoTest {
 
     // Invalid: Supported->Specified, Enabled->Unspecified
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <supported>true</supported>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <supported>true</supported>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -353,16 +359,16 @@ public class ServiceInfoTest {
 
     // Invalid: Supported->Unspecified, Enabled->Specified
     serviceInfoXml = "<metainfo>\n" +
-            "  <schemaVersion>2.0</schemaVersion>\n" +
-            "  <services>\n" +
-            "    <service>\n" +
-            "      <name>RANGER</name>\n" +
-            "      <credential-store>\n" +
-            "          <enabled>true</enabled>\n" +
-            "      </credential-store>\n" +
-            "    </service>\n" +
-            "  </services>\n" +
-            "</metainfo>\n";
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>RANGER</name>\n" +
+        "      <credential-store>\n" +
+        "          <enabled>true</enabled>\n" +
+        "      </credential-store>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
 
     serviceInfoMap = getServiceInfo(serviceInfoXml);
     serviceInfo = serviceInfoMap.get("RANGER");
@@ -383,25 +389,25 @@ public class ServiceInfoTest {
   @Test
   public void testServiceProperties() throws Exception {
     String serviceInfoXml =
-      "<metainfo>" +
-      "  <schemaVersion>2.0</schemaVersion>" +
-      "  <services>" +
-      "    <service>" +
-      "      <name>WITH_PROPS</name>" +
-      "      <displayName>WITH_PROPS</displayName>" +
-      "      <properties>" +
-      "        <property>" +
-      "          <name>PROP1</name>" +
-      "          <value>VAL1</value>" +
-      "        </property>" +
-      "        <property>" +
-      "          <name>PROP2</name>" +
-      "          <value>VAL2</value>" +
-      "        </property>" +
-      "      </properties>" +
-      "    </service>" +
-      "  </services>" +
-      "</metainfo>";
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>WITH_PROPS</name>" +
+            "      <displayName>WITH_PROPS</displayName>" +
+            "      <properties>" +
+            "        <property>" +
+            "          <name>PROP1</name>" +
+            "          <value>VAL1</value>" +
+            "        </property>" +
+            "        <property>" +
+            "          <name>PROP2</name>" +
+            "          <value>VAL2</value>" +
+            "        </property>" +
+            "      </properties>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
 
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
 
@@ -420,25 +426,25 @@ public class ServiceInfoTest {
   public void testDefaultVisibilityServiceProperties() throws Exception {
     // Given
     String serviceInfoXml =
-      "<metainfo>" +
-        "  <schemaVersion>2.0</schemaVersion>" +
-        "  <services>" +
-        "    <service>" +
-        "      <name>WITH_PROPS</name>" +
-        "      <displayName>WITH_PROPS</displayName>" +
-        "      <properties>" +
-        "        <property>" +
-        "          <name>PROP1</name>" +
-        "          <value>VAL1</value>" +
-        "        </property>" +
-        "        <property>" +
-        "          <name>PROP2</name>" +
-        "          <value>VAL2</value>" +
-        "        </property>" +
-        "      </properties>" +
-        "    </service>" +
-        "  </services>" +
-        "</metainfo>";
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>WITH_PROPS</name>" +
+            "      <displayName>WITH_PROPS</displayName>" +
+            "      <properties>" +
+            "        <property>" +
+            "          <name>PROP1</name>" +
+            "          <value>VAL1</value>" +
+            "        </property>" +
+            "        <property>" +
+            "          <name>PROP2</name>" +
+            "          <value>VAL2</value>" +
+            "        </property>" +
+            "      </properties>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
 
     // When
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
@@ -456,29 +462,29 @@ public class ServiceInfoTest {
   public void testVisibilityServicePropertyOverride() throws Exception {
     // Given
     String serviceInfoXml =
-      "<metainfo>" +
-        "  <schemaVersion>2.0</schemaVersion>" +
-        "  <services>" +
-        "    <service>" +
-        "      <name>WITH_PROPS</name>" +
-        "      <displayName>WITH_PROPS</displayName>" +
-        "      <properties>" +
-        "        <property>" +
-        "          <name>PROP1</name>" +
-        "          <value>VAL1</value>" +
-        "        </property>" +
-        "        <property>" +
-        "          <name>PROP2</name>" +
-        "          <value>VAL2</value>" +
-        "        </property>" +
-        "        <property>" +
-        "          <name>managed</name>" +
-        "          <value>false</value>" +
-        "        </property>" +
-        "      </properties>" +
-        "    </service>" +
-        "  </services>" +
-        "</metainfo>";
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>WITH_PROPS</name>" +
+            "      <displayName>WITH_PROPS</displayName>" +
+            "      <properties>" +
+            "        <property>" +
+            "          <name>PROP1</name>" +
+            "          <value>VAL1</value>" +
+            "        </property>" +
+            "        <property>" +
+            "          <name>PROP2</name>" +
+            "          <value>VAL2</value>" +
+            "        </property>" +
+            "        <property>" +
+            "          <name>managed</name>" +
+            "          <value>false</value>" +
+            "        </property>" +
+            "      </properties>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
 
     // When
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
@@ -494,34 +500,33 @@ public class ServiceInfoTest {
   }
 
   @Test
-  public void testDuplicateServicePropertyValidationAfterXmlDeserialization() throws Exception
-  {
+  public void testDuplicateServicePropertyValidationAfterXmlDeserialization() throws Exception {
     // Given
     String serviceInfoXml =
-      "<metainfo>" +
-        "  <schemaVersion>2.0</schemaVersion>" +
-        "  <services>" +
-        "    <service>" +
-        "      <version>1.0</version>" +
-        "      <name>WITH_DUPLICATE_PROPS</name>" +
-        "      <displayName>WITH_PROPS</displayName>" +
-        "      <properties>" +
-        "        <property>" +
-        "          <name>PROP1</name>" +
-        "          <value>VAL1</value>" +
-        "        </property>" +
-        "        <property>" +
-        "          <name>PROP1</name>" +
-        "          <value>VAL2</value>" +
-        "        </property>" +
-        "        <property>" +
-        "          <name>managed</name>" +
-        "          <value>false</value>" +
-        "        </property>" +
-        "      </properties>" +
-        "    </service>" +
-        "  </services>" +
-        "</metainfo>";
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <version>1.0</version>" +
+            "      <name>WITH_DUPLICATE_PROPS</name>" +
+            "      <displayName>WITH_PROPS</displayName>" +
+            "      <properties>" +
+            "        <property>" +
+            "          <name>PROP1</name>" +
+            "          <value>VAL1</value>" +
+            "        </property>" +
+            "        <property>" +
+            "          <name>PROP1</name>" +
+            "          <value>VAL2</value>" +
+            "        </property>" +
+            "        <property>" +
+            "          <name>managed</name>" +
+            "          <value>false</value>" +
+            "        </property>" +
+            "      </properties>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
 
     // When
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
@@ -561,45 +566,44 @@ public class ServiceInfoTest {
 
 
   @Test
-  public void testMultiplePimaryLogsValidationAfterXmlDeserialization() throws Exception
-  {
+  public void testMultiplePimaryLogsValidationAfterXmlDeserialization() throws Exception {
     // Given
     String serviceInfoXml =
         "<metainfo>" +
-        "  <schemaVersion>2.0</schemaVersion>" +
-        "  <services>" +
-        "    <service>" +
-        "      <version>1.0</version>" +
-        "      <name>WITH_MULTIPLE_PRIMARY_LOGS</name>" +
-        "      <displayName>WITH_MULTIPLE_PRIMARY_LOGS</displayName>" +
-        "      <properties>" +
-        "        <property>" +
-        "          <name>managed</name>" +
-        "          <value>false</value>" +
-        "        </property>" +
-        "      </properties>" +
-        "      <components> " +
-        "        <component> " +
-        "          <name>COMPONENT_WITH_MULTIPLE_PRIMARY_LOG</name> " +
-        "          <displayName>COMPONENT_WITH_MULTIPLE_PRIMARY_LOG</displayName> " +
-        "          <category>MASTER</category> " +
-        "          <cardinality>0-1</cardinality> " +
-        "          <versionAdvertised>true</versionAdvertised> " +
-        "          <logs> " +
-        "            <log> " +
-        "              <logId>log1</logId> " +
-        "              <primary>true</primary> " +
-        "            </log> " +
-        "            <log> " +
-        "              <logId>log2</logId> " +
-        "              <primary>true</primary> " +
-        "            </log> " +
-        "          </logs> " +
-        "       </component> " +
-        "      </components> " +
-        "    </service>" +
-        "  </services>" +
-        "</metainfo>";
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <version>1.0</version>" +
+            "      <name>WITH_MULTIPLE_PRIMARY_LOGS</name>" +
+            "      <displayName>WITH_MULTIPLE_PRIMARY_LOGS</displayName>" +
+            "      <properties>" +
+            "        <property>" +
+            "          <name>managed</name>" +
+            "          <value>false</value>" +
+            "        </property>" +
+            "      </properties>" +
+            "      <components> " +
+            "        <component> " +
+            "          <name>COMPONENT_WITH_MULTIPLE_PRIMARY_LOG</name> " +
+            "          <displayName>COMPONENT_WITH_MULTIPLE_PRIMARY_LOG</displayName> " +
+            "          <category>MASTER</category> " +
+            "          <cardinality>0-1</cardinality> " +
+            "          <versionAdvertised>true</versionAdvertised> " +
+            "          <logs> " +
+            "            <log> " +
+            "              <logId>log1</logId> " +
+            "              <primary>true</primary> " +
+            "            </log> " +
+            "            <log> " +
+            "              <logId>log2</logId> " +
+            "              <primary>true</primary> " +
+            "            </log> " +
+            "          </logs> " +
+            "       </component> " +
+            "      </components> " +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
 
     // When
     Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
@@ -646,13 +650,211 @@ public class ServiceInfoTest {
     assertTrue("true".equals(serviceProperties.get(ServiceInfo.DEFAULT_SERVICE_MONITORED_PROPERTY.getKey())));
   }
 
-  public static Map<String, ServiceInfo> getServiceInfo(String xml) throws JAXBException {
+  @Test
+  public void testSupportDeleteViaUI() throws Exception {
+    //Explicitly set to true
+    String serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>HDFS</name>" +
+            "      <displayName>HDFS</displayName>" +
+            "      <supportDeleteViaUI>true</supportDeleteViaUI>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertTrue(serviceInfoMap.get("HDFS").isSupportDeleteViaUI());
+
+    //Explicitly set to false
+    serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>HDFS</name>" +
+            "      <displayName>HDFS</displayName>" +
+            "      <supportDeleteViaUI>false</supportDeleteViaUI>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertFalse(serviceInfoMap.get("HDFS").isSupportDeleteViaUI());
+
+    //Default to true
+    serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>HDFS</name>" +
+            "      <displayName>HDFS</displayName>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertTrue(serviceInfoMap.get("HDFS").isSupportDeleteViaUI());
+  }
+
+  @Test
+  public void testSingleSignOnSupport() throws JAXBException {
+    // Implicit SSO setting
+    String serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>SERVICE</name>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    Map<String, ServiceInfo> serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertFalse(serviceInfoMap.get("SERVICE").isSingleSignOnSupported());
+    assertTrue(serviceInfoMap.get("SERVICE").isValid());
+
+    SingleSignOnInfo singleSignOnInfo = serviceInfoMap.get("SERVICE").getSingleSignOnInfo();
+    assertNull(singleSignOnInfo);
+
+    // Explicit SSO setting (true)
+    serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>SERVICE</name>" +
+            "      <sso>" +
+            "        <supported>true</supported>" +
+            "        <enabledConfiguration>config-type/property_name</enabledConfiguration>" +
+            "        <kerberosRequired>true</kerberosRequired> " +
+            "      </sso>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertTrue(serviceInfoMap.get("SERVICE").isSingleSignOnSupported());
+    assertTrue(serviceInfoMap.get("SERVICE").isValid());
+
+    singleSignOnInfo = serviceInfoMap.get("SERVICE").getSingleSignOnInfo();
+    assertNotNull(singleSignOnInfo);
+    assertTrue(singleSignOnInfo.isSupported());
+    assertEquals(Boolean.TRUE, singleSignOnInfo.getSupported());
+    assertEquals("config-type/property_name", singleSignOnInfo.getEnabledConfiguration());
+    assertTrue(singleSignOnInfo.isKerberosRequired());
+
+    // Explicit SSO setting (false)
+    serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>SERVICE</name>" +
+            "      <sso>" +
+            "        <supported>false</supported>" +
+            "      </sso>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertFalse(serviceInfoMap.get("SERVICE").isSingleSignOnSupported());
+    assertTrue(serviceInfoMap.get("SERVICE").isValid());
+
+    singleSignOnInfo = serviceInfoMap.get("SERVICE").getSingleSignOnInfo();
+    assertNotNull(singleSignOnInfo);
+    assertFalse(singleSignOnInfo.isSupported());
+    assertEquals(Boolean.FALSE, singleSignOnInfo.getSupported());
+    assertNull(singleSignOnInfo.getEnabledConfiguration());
+
+    // Explicit SSO setting (invalid)
+    serviceInfoXml =
+        "<metainfo>" +
+            "  <schemaVersion>2.0</schemaVersion>" +
+            "  <services>" +
+            "    <service>" +
+            "      <name>SERVICE</name>" +
+            "      <sso>" +
+            "        <supported>true</supported>" +
+            "      </sso>" +
+            "    </service>" +
+            "  </services>" +
+            "</metainfo>";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    assertTrue(serviceInfoMap.get("SERVICE").isSingleSignOnSupported());
+    assertFalse(serviceInfoMap.get("SERVICE").isValid());
+    assertEquals(1, serviceInfoMap.get("SERVICE").getErrors().size());
+
+    singleSignOnInfo = serviceInfoMap.get("SERVICE").getSingleSignOnInfo();
+    assertNotNull(singleSignOnInfo);
+    assertTrue(singleSignOnInfo.isSupported());
+    assertEquals(Boolean.TRUE, singleSignOnInfo.getSupported());
+    assertNull(singleSignOnInfo.getEnabledConfiguration());
+    assertNull(singleSignOnInfo.getSsoEnabledTest());
+  }
+
+  /**
+   * Tests the presence and absence of the kerberosEnabledTest block.
+   */
+  @Test
+  public void testKerberosEnabledTest() throws Exception {
+    Map<String, ServiceInfo> serviceInfoMap;
+    ServiceInfo service;
+
+    String kerberosEnabledTest =
+        "{\n" +
+            "  \"or\": [\n" +
+            "    {\n" +
+            "      \"equals\": [\n" +
+            "        \"core-site/hadoop.security.authentication\",\n" +
+            "        \"kerberos\"\n" +
+            "      ]\n" +
+            "    },\n" +
+            "    {\n" +
+            "      \"equals\": [\n" +
+            "        \"hdfs-site/hadoop.security.authentication\",\n" +
+            "        \"kerberos\"\n" +
+            "      ]\n" +
+            "    }\n" +
+            "  ]\n" +
+            "}";
+
+    String serviceInfoXml = "<metainfo>\n" +
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>HDFS</name>\n" +
+        "      <kerberosEnabledTest>\n" +
+        kerberosEnabledTest +
+        "      </kerberosEnabledTest>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    service = serviceInfoMap.get("HDFS");
+    assertEquals(kerberosEnabledTest, service.getKerberosEnabledTest().trim());
+
+    /*
+     * <kerberosEnabledTest> is missing
+     */
+    serviceInfoXml = "<metainfo>\n" +
+        "  <schemaVersion>2.0</schemaVersion>\n" +
+        "  <services>\n" +
+        "    <service>\n" +
+        "      <name>HDFS</name>\n" +
+        "    </service>\n" +
+        "  </services>\n" +
+        "</metainfo>\n";
+    serviceInfoMap = getServiceInfo(serviceInfoXml);
+    service = serviceInfoMap.get("HDFS");
+    assertNull(service.getKerberosEnabledTest());
+  }
+
+  private static Map<String, ServiceInfo> getServiceInfo(String xml) throws JAXBException {
     InputStream configStream = new ByteArrayInputStream(xml.getBytes());
     JAXBContext jaxbContext = JAXBContext.newInstance(ServiceMetainfoXml.class);
     Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
     ServiceMetainfoXml serviceMetainfoXml = (ServiceMetainfoXml) unmarshaller.unmarshal(configStream);
 
-    Map<String, ServiceInfo> serviceInfoMap = new HashMap<String, ServiceInfo>();
+    Map<String, ServiceInfo> serviceInfoMap = new HashMap<>();
     for (ServiceInfo serviceInfo : serviceMetainfoXml.getServices()) {
       serviceInfoMap.put(serviceInfo.getName(), serviceInfo);
     }
