@@ -17,12 +17,10 @@
  */
 
 var App = require('app');
-var blueprintUtils = require('utils/blueprint');
 require('controllers/wizard/step7_controller');
 
 App.KerberosWizardStep4Controller = App.WizardStep7Controller.extend(App.AddSecurityConfigs, App.ToggleIsRequiredMixin, App.KDCCredentialsControllerMixin, {
   name: 'kerberosWizardStep4Controller',
-  isWithinAddService: Em.computed.equal('wizardController.name', 'addServiceController'),
 
   // stores configurations loaded by ConfigurationsController.getConfigsByTags
   servicesConfigurations: null,
@@ -36,10 +34,6 @@ App.KerberosWizardStep4Controller = App.WizardStep7Controller.extend(App.AddSecu
 
   loadStep: function() {
     var self, stored;
-    if (this.get('wizardController.skipConfigureIdentitiesStep')) {
-      App.router.send('next');
-      return;
-    }
     self = this;
     this.clearStep();
     stored = this.get('wizardController').loadCachedStepConfigValues(this) || [];
@@ -72,25 +66,12 @@ App.KerberosWizardStep4Controller = App.WizardStep7Controller.extend(App.AddSecu
    * @returns {$.Deferred}
    */
   getDescriptor: function() {
-    var self = this;
     var dfd = $.Deferred();
     var successCallback = function(data) {
       dfd.resolve(data);
     };
-    var checkDescriptor = function() {
-      if (self.get('isWithinAddService')) {
-        return App.ajax.send({
-          sender: self,
-          name: 'admin.kerberize.cluster_descriptor_artifact'
-        });
-      }
-      return $.Deferred().resolve().promise();
-    };
 
-    checkDescriptor().always(function(data, status) {
-      self.storeClusterDescriptorStatus(status === 'success');
-      self.loadClusterDescriptorConfigs(self.get('isWithinAddService') ? self.get('selectedServiceNames') : false).then(successCallback);
-    });
+    this.loadClusterDescriptorConfigs(false).then(successCallback);
     return dfd.promise();
   },
 
@@ -485,32 +466,6 @@ App.KerberosWizardStep4Controller = App.WizardStep7Controller.extend(App.AddSecu
     return dfd.promise();
   },
 
-  /**
-   * Returns payload for recommendations request.
-   * Takes services' configurations and merge them with kerberos descriptor properties.
-   *
-   * @param {object[]} configurations services' configurations fetched from API
-   * @param {App.ServiceConfigProperty[]} kerberosDescriptor descriptor configs
-   * @returns {object} payload for recommendations request
-   */
-  getBlueprintPayloadObject: function(configurations, kerberosDescriptor) {
-    var recommendations = blueprintUtils.generateHostGroups(App.get('allHostNames'));
-    var mergedConfigurations = this.mergeDescriptorToConfigurations(configurations, this.createServicesStackDescriptorConfigs(kerberosDescriptor));
-    recommendations.blueprint.configurations = mergedConfigurations.reduce(function(p, c) {
-      p[c.type] = {};
-      p[c.type].properties = c.properties;
-      return p;
-    }, {});
-
-    if (this.get('isWithinAddService')) {
-      this.get('content.masterComponentHosts').filterProperty('isInstalled', false).forEach(function(item) {
-        var hostGroupName = blueprintUtils.getHostGroupByFqdn(recommendations, item.hostName);
-        blueprintUtils.addComponentToHostGroup(recommendations, item.component, hostGroupName);
-      }, this);
-    }
-    return recommendations;
-  },
-
   /**
    * @override
    */
@@ -557,89 +512,6 @@ App.KerberosWizardStep4Controller = App.WizardStep7Controller.extend(App.AddSecu
    */
   getServicesConfigObject: function() {
     return this.get('stepConfigs').findProperty('name', 'ADVANCED');
-  },
-
-  /**
-   * Returns map with appropriate action and properties to process with.
-   * Key is an action e.g. `add`, `update`, `delete` and value is  an object `fileName` -> `propertyName`: `propertyValue`.
-   *
-   * @param {object} recommendedConfigurations
-   * @param {object[]} servicesConfigurations services' configurations fetched from API
-   * @param {App.ServiceConfigProperty[]} allConfigs all current configurations stored in controller, basically kerberos descriptor
-   * @returns {object}
-   */
-  groupRecommendationProperties: function(recommendedConfigurations, servicesConfigurations, allConfigs) {
-    var resultMap = {
-      update: {},
-      add: {},
-      delete: {}
-    };
-
-    /**
-     * Adds property to associated group `add`,`delete`,`update`.
-     *
-     * @param {object} propertyMap <code>resultMap</code> object
-     * @param {string} name property name
-     * @param {string} propertyValue property value
-     * @param {string} fileName property file name
-     * @return {object} <code>resultMap</code>
-     * @param {string} group, `add`,`delete`,`update`
-     */
-    var addProperty = function(propertyMap, name, propertyValue, fileName, group) {
-      var ret = $.extend(true, {}, propertyMap);
-      if (ret.hasOwnProperty(group)) {
-        if (!ret[group].hasOwnProperty(fileName)) {
-          ret[group][fileName] = {};
-        }
-        ret[group][fileName][name] = propertyValue;
-      }
-      return ret;
-    };
-
-    return Em.keys(recommendedConfigurations || {}).reduce(function(acc, fileName) {
-      var propertyMap = acc;
-      var recommendedProperties = Em.getWithDefault(recommendedConfigurations, fileName + '.properties', {});
-      var recommendedAttributes = Em.getWithDefault(recommendedConfigurations, fileName + '.property_attributes', {});
-      // check for properties that should be delted
-      Em.keys(recommendedAttributes).forEach(function(propertyName) {
-        var attribute = recommendedAttributes[propertyName];
-        // delete properties which are present in kerberos descriptor
-        if (attribute.hasOwnProperty('delete') && allConfigs.filterProperty('filename', fileName).someProperty('name', propertyName)) {
-          propertyMap = addProperty(propertyMap, propertyName, '', fileName, 'delete');
-        }
-      });
-
-      return Em.keys(recommendedProperties).reduce(function(a, propertyName) {
-        var propertyValue = recommendedProperties[propertyName];
-        // check if property exist in saved configurations on server
-        var isExist = Em.getWithDefault(servicesConfigurations.findProperty('type', fileName) || {}, 'properties', {}).hasOwnProperty(propertyName);
-        if (!isExist) {
-          return addProperty(a, propertyName, propertyValue, fileName, 'add');
-        }
-        // when property exist check that it present in current step configs (kerberos descriptor)
-        // and add it as property to `update`
-        if (allConfigs.filterProperty('filename', fileName).someProperty('name', propertyName)) {
-          return addProperty(a, propertyName, propertyValue, fileName, 'update');
-        }
-        return a;
-      }, propertyMap);
-    }, resultMap);
-  },
-
-  /**
-   *
-   * @method getServiceByFilename
-   * @param {string}fileName
-   * @returns {string}
-   */
-  getServiceByFilename: function(fileName) {
-    // core-site properties goes to HDFS
-    if (fileName === 'core-site' && App.Service.find().someProperty('serviceName', 'HDFS')) {
-      return 'HDFS';
-    }
-    var associatedService = App.StackService.find().filter(function(service) {
-      return Em.keys(service.get('configTypes')).contains(fileName);
-    })[0];
-    return associatedService ? associatedService.get('serviceName') : '';
   }
+
 });
