@@ -30,9 +30,7 @@ App.MainHostController = Em.ArrayController.extend(App.TableServerMixin, {
    * total number of installed hosts
    * @type {number}
    */
-  totalCount: function () {
-    return this.get('hostsCountMap')['TOTAL'] || 0;
-  }.property('hostsCountMap'),
+  totalCount: Em.computed.alias('App.allHostNames.length'),
 
   /**
    * @type {boolean}
@@ -40,13 +38,6 @@ App.MainHostController = Em.ArrayController.extend(App.TableServerMixin, {
    */
   resetStartIndex: false,
 
-  /**
-   * flag responsible for updating status counters of hosts
-   */
-  isCountersUpdating: false,
-
-  hostsCountMap: {},
-
   startIndex: 1,
 
   /**
@@ -59,6 +50,8 @@ App.MainHostController = Em.ArrayController.extend(App.TableServerMixin, {
    */
   showFilterConditionsFirstLoad: false,
 
+  saveSelection: false,
+
   content: App.Host.find(),
 
   allHostStackVersions: App.HostStackVersion.find(),
@@ -335,51 +328,6 @@ App.MainHostController = Em.ArrayController.extend(App.TableServerMixin, {
     return queryParams;
   },
 
-  /**
-   * update status counters of hosts
-   */
-  updateStatusCounters: function () {
-    var self = this;
-
-    if (this.get('isCountersUpdating')) {
-      App.ajax.send({
-        name: 'host.status.counters',
-        sender: this,
-        data: {},
-        success: 'updateStatusCountersSuccessCallback',
-        error: 'updateStatusCountersErrorCallback',
-        callback: function() {
-          setTimeout(function () {
-            self.updateStatusCounters();
-          }, App.get('hostStatusCountersUpdateInterval'));
-        }
-      });
-    }
-  },
-
-  /**
-   * success callback on <code>updateStatusCounters()</code>
-   * map counters' value to categories
-   * @param data
-   */
-  updateStatusCountersSuccessCallback: function (data) {
-    var hostsCountMap = {
-      'HEALTHY': data.Clusters.health_report['Host/host_status/HEALTHY'],
-      'UNHEALTHY': data.Clusters.health_report['Host/host_status/UNHEALTHY'],
-      'ALERT': data.Clusters.health_report['Host/host_status/ALERT'],
-      'UNKNOWN': data.Clusters.health_report['Host/host_status/UNKNOWN'],
-      'health-status-RESTART': data.Clusters.health_report['Host/stale_config'],
-      'health-status-PASSIVE_STATE': data.Clusters.health_report['Host/maintenance_state'],
-      'TOTAL': data.Clusters.total_hosts
-    };
-
-    this.set('hostsCountMap', hostsCountMap);
-  },
-
-  /**
-   * success callback on <code>updateStatusCounters()</code>
-   */
-  updateStatusCountersErrorCallback: Em.K,
 
   /**
    * Return value without predicate
