@@ -424,7 +424,7 @@ App.WizardStep9Controller = Em.Controller.extend(App.ReloadPopupMixin, {
         }
         break;
       case 'CUSTOM_COMMAND':
-        role = App.format.commandDetail(task.command_detail, task.request_input);
+        role = App.format.commandDetail(task.command_detail, task.request_input, task.ops_display_name);
       case 'EXECUTE' :
       case 'SERVICE_CHECK' :
         switch (task.status) {
@@ -606,11 +606,9 @@ App.WizardStep9Controller = Em.Controller.extend(App.ReloadPopupMixin, {
       encodeBody: false,
       primary: Em.I18n.t('ok'),
       header: Em.I18n.t('installer.step9.service.start.header'),
-      secondaryClass: "hide",
+      secondary: false,
       body: Em.I18n.t('installer.step9.service.start.failed'),
-      primaryClass: 'btn-success',
-      onPrimary: function() { this.hide(); },
-      onClose: function() { this.hide(); }
+      'data-qa': 'start-failed-modal'
     });
   },
 
