@@ -31,6 +31,6 @@ App.ActivateHawqStandbyWizardStep3View = App.HighAvailabilityProgressPageView.ex
 
   submitButtonText: Em.I18n.t('common.complete'),
 
-  labelWidth: 'span5'
+  labelWidth: 'col-md-5'
 
 });
