@@ -74,8 +74,9 @@ describe('App.HighAvailabilityWizardStep3Controller', function() {
   };
 
   beforeEach(function () {
-    controller = App.HighAvailabilityWizardStep3Controller.create();
-    controller.set('serverConfigData', serverConfigData);
+    controller = App.HighAvailabilityWizardStep3Controller.create({
+      serverConfigData: serverConfigData
+    });
   });
 
   afterEach(function () {
@@ -418,17 +419,35 @@ describe('App.HighAvailabilityWizardStep3Controller', function() {
 
   describe('#onLoadConfigsTags', function () {
 
-    var data = {Clusters: {desired_configs: {
-      'hdfs-site': {tag: 'v1'},
-      'core-site': {tag: 'v2'},
-      'zoo.cfg': {tag: 'v3'},
-      'hbase-site': {tag: 'v4'},
-      'accumulo-site': {tag: 'v5'},
-      'ams-hbase-site': {tag: 'v6'},
-      'hawq-site': {tag: 'v7'},
-      'hdfs-client': {tag: 'v8'},
-      'ranger-env': {tag: 'v9'}
-    }}};
+    var data = {
+      Clusters: {
+        desired_configs: {
+          'hdfs-site': {tag: 'v1'},
+          'core-site': {tag: 'v2'},
+          'zoo.cfg': {tag: 'v3'},
+          'hbase-site': {tag: 'v4'},
+          'accumulo-site': {tag: 'v5'},
+          'ams-hbase-site': {tag: 'v6'},
+          'hawq-site': {tag: 'v7'},
+          'hdfs-client': {tag: 'v8'},
+          'ranger-env': {tag: 'v9'},
+          'ranger-hdfs-plugin-properties': {tag: 'v10'},
+          'ranger-hdfs-audit': {tag: 'v11'},
+          'ranger-yarn-audit': {tag: 'v12'},
+          'ranger-hbase-audit': {tag: 'v13'},
+          'ranger-hbase-plugin-properties': {tag: 'v14'},
+          'ranger-kafka-audit': {tag: 'v15'},
+          'ranger-knox-audit': {tag: 'v16'},
+          'ranger-knox-plugin-properties': {tag: 'v17'},
+          'ranger-storm-audit': {tag: 'v18'},
+          'ranger-storm-plugin-properties': {tag: 'v19'},
+          'ranger-atlas-audit': {tag: 'v20'},
+          'ranger-hive-audit': {tag: 'v21'},
+          'ranger-hive-plugin-properties': {tag: 'v22'},
+          'ranger-kms-audit': {tag: 'v23'}
+        }
+      }
+    };
 
     beforeEach(function () {
       sinon.stub(App.Service, 'find', function () {
@@ -437,7 +456,13 @@ describe('App.HighAvailabilityWizardStep3Controller', function() {
           Em.Object.create({serviceName: 'ACCUMULO'}),
           Em.Object.create({serviceName: 'AMBARI_METRICS'}),
           Em.Object.create({serviceName: 'HAWQ'}),
-          Em.Object.create({serviceName: 'RANGER'})
+          Em.Object.create({serviceName: 'RANGER'}),
+          Em.Object.create({serviceName: 'RANGER_KMS'}),
+          Em.Object.create({serviceName: 'HIVE'}),
+          Em.Object.create({serviceName: 'ATLAS'}),
+          Em.Object.create({serviceName: 'STORM'}),
+          Em.Object.create({serviceName: 'KNOX'}),
+          Em.Object.create({serviceName: 'KAFKA'})
         ];
       });
       controller.onLoadConfigsTags(data);
@@ -449,9 +474,236 @@ describe('App.HighAvailabilityWizardStep3Controller', function() {
     });
 
     it('urlParams are valid', function () {
-      expect(this.args[0].data.urlParams).to.be.equal('(type=hdfs-site&tag=v1)|(type=core-site&tag=v2)|(type=zoo.cfg&tag=v3)|(type=hbase-site&tag=v4)|(type=accumulo-site&tag=v5)|(type=ams-hbase-site&tag=v6)|(type=hawq-site&tag=v7)|(type=hdfs-client&tag=v8)|(type=ranger-env&tag=v9)');
+      expect(this.args[0].data.urlParams).to.be.equal('(type=hdfs-site&tag=v1)' +
+        '|(type=core-site&tag=v2)' +
+        '|(type=zoo.cfg&tag=v3)' +
+        '|(type=hbase-site&tag=v4)' +
+        '|(type=accumulo-site&tag=v5)' +
+        '|(type=ams-hbase-site&tag=v6)' +
+        '|(type=hawq-site&tag=v7)' +
+        '|(type=hdfs-client&tag=v8)' +
+        '|(type=ranger-env&tag=v9)' +
+        '|(type=ranger-hdfs-plugin-properties&tag=v10)' +
+        '|(type=ranger-hdfs-audit&tag=v11)' +
+        '|(type=ranger-yarn-audit&tag=v12)' +
+        '|(type=ranger-hbase-audit&tag=v13)' +
+        '|(type=ranger-hbase-plugin-properties&tag=v14)' +
+        '|(type=ranger-kafka-audit&tag=v15)' +
+        '|(type=ranger-knox-audit&tag=v16)' +
+        '|(type=ranger-knox-plugin-properties&tag=v17)' +
+        '|(type=ranger-storm-audit&tag=v18)' +
+        '|(type=ranger-storm-plugin-properties&tag=v19)' +
+        '|(type=ranger-atlas-audit&tag=v20)' +
+        '|(type=ranger-hive-audit&tag=v21)' +
+        '|(type=ranger-hive-plugin-properties&tag=v22)' +
+        '|(type=ranger-kms-audit&tag=v23)'
+      );
+    });
+  });
+
+  describe('#clearStep', function() {
+
+    it('should clean data', function() {
+      controller.set('stepConfigs', [{}]);
+      controller.set('serverConfigData', {a: 1});
+      controller.clearStep();
+      expect(controller.get('stepConfigs')).to.be.empty;
+      expect(controller.get('serverConfigData')).to.be.empty;
+    });
+  });
+
+  describe('#loadStep', function() {
+    beforeEach(function() {
+      sinon.stub(controller, 'clearStep');
+      sinon.stub(controller, 'loadConfigsTags');
+      controller.loadStep();
+    });
+    afterEach(function() {
+      controller.clearStep.restore();
+      controller.loadConfigsTags.restore();
     });
 
+    it('loadConfigsTags should be called', function() {
+      expect(controller.loadConfigsTags.calledOnce).to.be.true;
+    });
+
+    it('clearStep should be called', function() {
+      expect(controller.clearStep.calledOnce).to.be.true;
+    });
+  });
+
+  describe('#loadConfigsTags', function() {
+    it('App.ajax.send should be called', function() {
+      controller.loadConfigsTags();
+      expect(testHelpers.findAjaxRequest('name', 'config.tags')).to.be.exist;
+    });
+  });
+
+  describe('#onLoadConfigs', function() {
+    beforeEach(function() {
+      sinon.stub(controller, 'removeConfigs');
+      sinon.stub(controller, 'tweakServiceConfigs');
+      sinon.stub(controller, 'renderServiceConfigs');
+      controller.set('configsToRemove', [{}]);
+      controller.set('haConfig', Em.Object.create({
+        configs: []
+      }));
+      controller.onLoadConfigs({a: 1});
+    });
+    afterEach(function() {
+      controller.tweakServiceConfigs.restore();
+      controller.removeConfigs.restore();
+      controller.renderServiceConfigs.restore();
+    });
+
+    it('serviceConfigData should be set', function() {
+      expect(controller.get('serverConfigData')).to.be.eql({a: 1});
+    });
+
+    it('removeConfigs should be called', function() {
+      expect(controller.removeConfigs.calledWith([{}], {a: 1})).to.be.true;
+    });
+
+    it('tweakServiceConfigs should be called', function() {
+      expect(controller.tweakServiceConfigs.calledWith([])).to.be.true;
+    });
+
+    it('renderServiceConfigs should be called', function() {
+      expect(controller.renderServiceConfigs.calledWith(Em.Object.create({
+        configs: []
+      }))).to.be.true;
+    });
+
+    it('isLoaded should be true', function() {
+      expect(controller.get('isLoaded')).to.be.true;
+    });
+  });
+
+  describe('#renderServiceConfigs', function() {
+    var serviceConfig = {
+      serviceName: 'S1',
+      displayName: 's1',
+      configCategories: [
+        {
+          name: 'C1',
+          errorCount: 0
+        },
+        {
+          name: 'C2',
+          errorCount: 0
+        }
+      ]
+    };
+    beforeEach(function() {
+      sinon.stub(controller, 'loadComponentConfigs');
+      sinon.stub(App.Service, 'find').returns([Em.Object.create({serviceName: 'C1'})]);
+
+      controller.renderServiceConfigs(serviceConfig);
+    });
+    afterEach(function() {
+      controller.loadComponentConfigs.restore();
+      App.Service.find.restore();
+    });
+
+    it('serviceConfig should be pushed in stepConfigs', function() {
+      expect(controller.get('stepConfigs')).to.have.length(1);
+    });
+
+    it('selectedService should be set', function() {
+      expect(JSON.stringify(controller.get('selectedService.configCategories'))).to.be.equal(JSON.stringify([{
+        name: 'C1',
+        errorCount: 0
+      }]));
+      expect(controller.get('selectedService.serviceName')).to.be.equal('S1');
+      expect(controller.get('selectedService.displayName')).to.be.equal('s1');
+      expect(controller.get('selectedService.showConfig')).to.be.true;
+      expect(controller.get('selectedService.configs')).to.be.empty;
+    });
+
+    it('once should be true', function() {
+      expect(controller.get('once')).to.be.true;
+    });
+  });
+
+  describe('#loadComponentConfigs', function() {
+
+    it('should push configs', function() {
+      var _componentConfig = {
+        configs: [{
+          isReconfigurable: true
+        }]
+      };
+      var componentConfig = {
+        configs: []
+      };
+      controller.loadComponentConfigs(_componentConfig, componentConfig);
+      expect(componentConfig.configs).to.have.length(1);
+      expect(componentConfig.configs[0].get('isEditable')).to.be.true;
+    });
+  });
+
+  describe('#_prepareLocalDB', function() {
+    beforeEach(function() {
+      sinon.stub(App.Service, 'find').returns([{serviceName: 'S1'}]);
+    });
+    afterEach(function() {
+      App.Service.find.restore();
+    });
+
+    it('should return localDb object', function() {
+      controller.set('content', Em.Object.create({
+        masterComponentHosts: [{}],
+        slaveComponentHosts: [{}],
+        hosts: [{}]
+      }));
+      expect(controller._prepareLocalDB()).to.be.eql({
+        masterComponentHosts: [{}],
+        slaveComponentHosts: [{}],
+        hosts: [{}],
+        installedServices: ['S1']
+      });
+    });
+  });
+
+  describe('#tweakServiceConfigs', function() {
+    beforeEach(function() {
+      sinon.stub(controller, '_prepareLocalDB');
+      sinon.stub(controller, '_prepareDependencies');
+      sinon.stub(App.NnHaConfigInitializer, 'initialValue');
+    });
+    afterEach(function() {
+      controller._prepareLocalDB.restore();
+      controller._prepareDependencies.restore();
+      App.NnHaConfigInitializer.initialValue.restore();
+    });
+
+    it('should modify configs', function() {
+      expect(controller.tweakServiceConfigs([{}])).to.be.eql([{isOverridable: false}]);
+    });
+  });
+
+  describe('#removeConfigs', function() {
+
+    it('should remove config properties', function() {
+      var configs = {
+        items: [
+          {
+            type: 'k1',
+            properties: {
+              p1: {}
+            }
+          }
+        ]
+      };
+      expect(JSON.stringify(controller.removeConfigs({k1: ['p1']}, configs))).to.be.equal(JSON.stringify({
+        items: [
+          {
+            type: 'k1',
+            properties: {}
+          }
+        ]
+      }));
+    });
   });
 
 });
