@@ -25,6 +25,11 @@ describe('App.ChartLinearTimeView', function () {
 
   beforeEach(function() {
     chartLinearTimeView = App.ChartLinearTimeView.create();
+    sinon.stub(App.ajax, 'abortRequests', Em.K);
+  });
+
+  afterEach(function () {
+    App.ajax.abortRequests.restore();
   });
 
   describe("#isRequestRunning", function () {
@@ -252,7 +257,6 @@ describe('App.ChartLinearTimeView', function () {
         fromSeconds: -3599,
         stepSeconds: 15,
         hostName: 'host1',
-        nameNodeName: '',
         resourceManager: ''
       });
     });
@@ -267,7 +271,6 @@ describe('App.ChartLinearTimeView', function () {
         fromSeconds: -3599,
         stepSeconds: 15,
         hostName: '',
-        nameNodeName: 'host1',
         resourceManager: ''
       });
       services.hdfsService = [];
@@ -283,7 +286,6 @@ describe('App.ChartLinearTimeView', function () {
         fromSeconds: -3599,
         stepSeconds: 15,
         hostName: '',
-        nameNodeName: 'host1',
         resourceManager: ''
       });
       services.hdfsService = [];
@@ -299,7 +301,6 @@ describe('App.ChartLinearTimeView', function () {
         fromSeconds: -3599,
         stepSeconds: 15,
         hostName: '',
-        nameNodeName: '',
         resourceManager: 'host1'
       });
       services.yarnService = [];
@@ -397,16 +398,11 @@ describe('App.ChartLinearTimeView', function () {
       describe(item.title, function () {
 
         beforeEach(function () {
-          sinon.stub(App.ajax, 'abortRequests', Em.K);
           view.set('inWidget', item.inWidget);
           view.set('parentView.isClusterMetricsWidget', item.isClusterMetricsWidget);
           view.propertyDidChange('parentView.currentTimeRangeIndex');
         });
 
-        afterEach(function () {
-          App.ajax.abortRequests.restore();
-        });
-
         it('parentView.isLoaded', function () {
           expect(view.get('parentView.isLoaded')).to.eql(item.parentViewIsLoaded);
         });
